@@ -19,7 +19,7 @@
  *	Added options -l to show size of message, and
  *	      option -d to output the date stamp additionally
  *
- *	/local/src-CVS/master/smail/contrib/smaillog/smaillog.c,v 1.7 1992/09/20 12:54:34 tron Exp
+ *	/cvs/master/smail/contrib/smaillog/smaillog.c,v 1.7 1992/09/20 12:54:34 tron Exp
  */
 
 
