@@ -1,7 +1,7 @@
 /* pathalias -- by steve bellovin, as told to peter honeyman */
 #ifndef lint
 static char	*sccsid = "@(#)domain.c	9.5 92/08/25";
-static char	*rcsid = "@(#)smail/pd/pathalias:RELEASE-3_2_0_101:domain.c,v 1.4 1997/05/26 21:43:47 woods Exp";
+static char	*rcsid = "@(#)smail/pd/pathalias:RELEASE-3_2_0_102:domain.c,v 1.5 1998/02/15 23:13:29 woods Exp";
 #endif /* lint */
 
 #define NEED_SOCKETS			/* only for smail-3 */
@@ -90,8 +90,6 @@ movetofront(headp, d)
 }
 
 #ifdef RESOLVER
-#include <sys/types.h>
-#include <arpa/nameser.h>
 
 nslookup(domain)
 	char *domain;
