@@ -1,5 +1,5 @@
 /*
-#ident	"@(#)smail/src:RELEASE-3_2_0_101:addr.c,v 1.24 1997/12/13 06:48:05 woods Exp"
+#ident	"@(#)smail/src:RELEASE-3_2_0_102:addr.c,v 1.26 1998/07/05 17:51:47 woods Exp"
  */
 
 /*
@@ -274,7 +274,7 @@ int
 parse_address(address, target, remainder, flagp)
     char *address;			/* address to parse (destructively) */
     char **target;			/* store pointer to target host here */
-    char **remainder;			/* store pointer to remainder here */
+    char **remainder;			/* store pointer to remainder here, or error msg txt on failure */
     int *flagp;				/* flag passed between invocations */
 {
     char *ep;				/* pointer to end of address */
@@ -320,20 +320,24 @@ parse_address(address, target, remainder, flagp)
 	    return FAIL;
 	}
 	if (*ap == ',' || *ap == ':') {
-	    int retval = (*ap==','? RFC_ROUTE: RFC_ENDROUTE);
+	    int retval = (*ap == ',' ? RFC_ROUTE : RFC_ENDROUTE);
+
 	    if (target) {
 		*ap++ = '\0';		/* null terminate target */
 		*remainder = ap;
 		if (check_target_and_remainder(target, remainder) == FAIL) {
 		    return FAIL;
 		}
-		DEBUG2(DBG_ADDR_HI,
-		       "parse_address: RFC_ROUTE: target=%s, remainder=%s\n",
+		DEBUG3(DBG_ADDR_HI,
+		       "parse_address: %s: target=%s, remainder=%s\n",
+		       retval == RFC_ROUTE ? "RFC_ROUTE" : "RFC_ENDROUTE",
 		       *target, *remainder);
+	    } else {
+		DEBUG(DBG_ADDR_HI, "parse_address: RFC_ROUTE.\n");
 	    }
 	    return retval;
 	}
-	/* we have a syntax error, missing , or : */
+	/* we have a syntax error, missing `,' or `:' */
 	*remainder = "syntax error: , or : missing in route-addr";
 	DEBUG1(DBG_ADDR_MID, "parse_address: %s\n", *remainder);
 	return FAIL;
@@ -371,6 +375,8 @@ parse_address(address, target, remainder, flagp)
 	    DEBUG2(DBG_ADDR_HI,
 		   "parse_address: MAILBOX: target=%s, remainder=%s\n",
 		   *target, *remainder);
+	} else {
+	    DEBUG(DBG_ADDR_HI, "parse_address: MAILBOX\n");
 	}
 	return MAILBOX;
     }
@@ -401,6 +407,8 @@ parse_address(address, target, remainder, flagp)
 	    DEBUG2(DBG_ADDR_HI,
 		   "parse_address: UUCP_ROUTE: target=%s, remainder=%s\n",
 		   *target, *remainder);
+	} else {
+	    DEBUG(DBG_ADDR_HI, "parse_address: UUCP_ROUTE\n");
 	}
 	return UUCP_ROUTE;
     }
@@ -423,6 +431,8 @@ parse_address(address, target, remainder, flagp)
 		DEBUG2(DBG_ADDR_HI,
 		       "parse_address: DECNET: target=%s, remainder=%s\n",
 		       *target, *remainder);
+	    } else {
+		DEBUG(DBG_ADDR_HI, "parse_address: DECNET\n");
 	    }
 	    return DECNET;
 	}
@@ -439,6 +449,8 @@ parse_address(address, target, remainder, flagp)
 	    DEBUG2(DBG_ADDR_HI,
 		   "parse_address: BERKENET: target=%s, remainder=%s\n",
 		   *target, *remainder);
+	} else {
+	    DEBUG(DBG_ADDR_HI, "parse_address: BERKENET\n");
 	}
 	return BERKENET;
 # endif /* USE_BERKENET */
@@ -465,6 +477,8 @@ parse_address(address, target, remainder, flagp)
 	    DEBUG2(DBG_ADDR_HI,
 		   "parse_address: PCT_MAILBOX: target=%s, remainder=%s\n",
 		   *target, *remainder);
+	} else {
+	    DEBUG(DBG_ADDR_HI, "parse_address: PCT_MAILBOX\n");
 	}
 	return PCT_MAILBOX;
     }
@@ -485,6 +499,8 @@ parse_address(address, target, remainder, flagp)
 	DEBUG2(DBG_ADDR_HI, "parse_address: LOCAL: target=%s, remainder=%s\n",
 	       *target ? *target : "(no-domain)", *remainder);
 #endif
+    } else {
+	DEBUG(DBG_ADDR_HI, "parse_address: LOCAL\n");
     }
     return LOCAL;
 }
@@ -1393,7 +1409,7 @@ note_error(info, message)
 {
     struct error *ret = (struct error *)xmalloc(sizeof(*ret));
 
-    DEBUG2(DBG_ADDR_LO, "note_error(%ld, %s)\n", info, message);
+    DEBUG2(DBG_ADDR_MID, "note_error(%ld, %s)\n", info, message);
 
     ret->info = info;
     ret->message = message;
