@@ -1,5 +1,5 @@
 /*
-#ident	"@(#)smail/src:RELEASE-3_2_0_101:alloc.h,v 1.7 1996/05/29 18:48:16 woods Exp"
+#ident	"@(#)smail/src:RELEASE-3_2_0_102:alloc.h,v 1.8 1998/04/11 23:30:10 woods Exp"
  */
 
 /*
@@ -58,8 +58,8 @@ struct bseg {
  */
 #define X_MAGIC	  ((ALIGNED_TYPE)0xe8f987b1)
 #define X_CHECK(p)							\
-	(((ALIGNED_TYPE *)(p))[-1] != X_MAGIC?					\
-		(write_log(LOG_PANIC,					\
+	(((ALIGNED_TYPE *)(p))[-1] != X_MAGIC?				\
+		(write_log(WRITE_LOG_PANIC,				\
 			"X_CHECK failed!  ptr=0x%lx, line=%d, file=%s", \
 			(long)(p), __LINE__, __FILE__),			\
 		 x_dont_panic?						\
