@@ -1,5 +1,5 @@
 /*
-#ident	"@(#)smail/src:RELEASE-3_2_0_101:bindlib.c,v 1.45 1997/12/02 00:30:36 woods Exp"
+#ident	"@(#)smail/src:RELEASE-3_2_0_102:bindlib.c,v 1.48 1998/06/08 01:56:07 woods Exp"
  */
 
 /*
@@ -518,7 +518,6 @@ bind_check_if_local_mxs(cur)
     if ((ret = find_mx_records(strip_target, mxdat, FALSE)) != DB_SUCCEED) {
 	DEBUG1(DBG_DRIVER_LO, "no MXs for %s.\n", strip_target);
 	mx_work_area_destructor(mxdat, FALSE);
-	xfree(strip_target);
 	_res.options = save_res_options;
 
         return ret;
@@ -526,7 +525,6 @@ bind_check_if_local_mxs(cur)
     if ((ret = decode_cnames(mxdat)) != DB_SUCCEED) {
 	DEBUG1(DBG_DRIVER_LO, "problem decoding cnames for %s.\n", strip_target);
 	mx_work_area_destructor(mxdat, FALSE);
-	xfree(strip_target);
 	_res.options = save_res_options;
 
         return ret;
@@ -534,7 +532,6 @@ bind_check_if_local_mxs(cur)
     if ((ret = make_mx_hints(mxdat)) != DB_SUCCEED) {
 	DEBUG1(DBG_DRIVER_LO, "problem finding MX hints for %s.\n", strip_target);
 	mx_work_area_destructor(mxdat, FALSE);
-	xfree(strip_target);
 	_res.options = save_res_options;
 
         return ret;
@@ -542,7 +539,6 @@ bind_check_if_local_mxs(cur)
     ret = (mxdat->local_precedence >= 0) ? (DB_SUCCEED + 1) : DB_SUCCEED;
 
     mx_work_area_destructor(mxdat, FALSE);
-    xfree(strip_target);
     _res.options = save_res_options;
 
     DEBUG1(DBG_DRIVER_MID, "bind_check_if_local_mxs() says %s.\n",
@@ -714,8 +710,7 @@ bind_addr_work(raw_target, flags, priv, what, rt_info, error_p)
          */
 
         if ((gateway = check_if_gatewayed(target, priv->gateways)) != NULL) {
-	    xfree(target);
-            target = strip_dots(gateway);
+	    target = COPY_STRING(strip_dots(gateway));
         }
 
         rt_info->matchlen = strlen(raw_target);
@@ -1224,13 +1219,16 @@ static int handle_null_mxs(mxdat, priv)
          * advertise any information about a particular name we will
          * give it the benefit of the doubt and attempt delivery.
          */
-
-	/* Check if local host because if it is we don't need address hints! */
+	/*
+	 * As long as we're allowed to filter, check if the target is a local
+	 * host because if it is then we won't need any address hints, and we
+	 * can save another DNS lookup.
+	 */
 	/*
 	 * XXX WARNING: things like wild-card MXs will break the islocalhost()
 	 * check!!!!
 	 */
-	if (islocalhost(mxdat->matched_target) && (mxdat->flags & BIND_LOCAL_MX_OKAY)) {
+	if (!(mxdat->flags & BIND_DONT_FILTER) && (mxdat->flags & BIND_LOCAL_MX_OKAY) && islocalhost(mxdat->matched_target)) {
 	    DEBUG1(DBG_DRIVER_HI, "handle_null_mxs: islocalhost(%s).\n", mxdat->matched_target);
 	    return DB_SUCCEED;
 	}
@@ -1602,11 +1600,16 @@ static void mx_work_area_destructor (mxdat, do_not_deallocate_mxhints)
 }
 
 
-  /* First see if the address matches one of the list of special
-   * gateways. If so, change the target to the gateway, and set
-   * the full_target to the original string so it will be passed
-   * on to the gateway. 
-   */
+/* check if the address given by target matches one of the domains given for a
+ * list of special gateways.  Gateways is a list of gateways and corresponding
+ * domains for explicit routing using the bind processing logic for the gateway
+ * address.  The string consists of a sequence of lists.  Each list consists of
+ * strings separated by colons, and the lists are separated by a string
+ * consisting of a single `+' character.  Each list consists of the name of a
+ * gateway, followed by a list of domains that should be routed to that
+ * gateway.  The gatewayed domains will match either against a complete
+ * address, or against the terminating domain of an address.
+ */
 
 static char * check_if_gatewayed (target, gateways)
      char * target;
@@ -1792,7 +1795,17 @@ get_records(qname, qtype, answer, pack_size, error)
     if (anslen < 0) {
         switch (h_errno) {
         case NO_DATA:
-            return DB_SUCCEED;
+	    /*
+	     * the rest of bindlib.c assumes that we have a valid packet
+	     * when we return DB_SUCCEED, so dummy one up that shows no
+	     * data was retrieved
+	     */
+	    answer->qdcount = 0;
+	    answer->ancount = 0;
+	    answer->nscount = 0;
+	    answer->arcount = 0;
+	    *pack_size = sizeof(HEADER);
+	    return DB_SUCCEED;
 
         case HOST_NOT_FOUND:
             return DB_NOMATCH;
@@ -1922,6 +1935,7 @@ rewindrr(it, hp, packsize)
                              MAXDNAME);
         if (dnamelen < 0) {
             it->ancount = it->nscount = it->arcount = 0;
+	    return;
         }
         it->dp += dnamelen;
         it->dp += 4;                    /* skip over class and type */
