@@ -1,5 +1,5 @@
 /*
-#ident	"@(#)smail/src:RELEASE-3_2_0_101:config.c,v 1.31 1997/10/18 14:57:38 woods Exp"
+#ident	"@(#)smail/src:RELEASE-3_2_0_102:config.c,v 1.33 1998/04/11 23:30:13 woods Exp"
  */
 
 /*
@@ -99,7 +99,7 @@ int smtp_debug = SMTP_DEBUG;		/* allow DEBUG command in SMTP */
 int smtp_info = SMTP_INFO;		/* allow EXPN/VRFY commanda in SMTP */
 char *smtp_remote_allow = SMTP_REMOTE_ALLOW; /* ip list that can send remote smtp */
 int smtp_hello_verify = SMTP_HELLO_VERIFY; /* verify HELO/EHLO host has A RR matching sockaddr */
-int smtp_hello_broken_allow = SMTP_HELLO_BROKEN_ALLOW; /* ip list that can avoid hello verification */
+char *smtp_hello_broken_allow = SMTP_HELLO_BROKEN_ALLOW; /* ip list that can avoid hello verification */
 int smtp_hello_verify_literal = SMTP_HELLO_VERIFY_LITERAL; /* verify HELO/EHLO domain literal has PTR RR */
 int smtp_hello_verify_ptr = SMTP_HELLO_VERIFY_PTR; /* verify HELO/EHLO matches PTR RR for sockaddr */
 int smtp_sender_verify_mx_only = SMTP_SENDER_VERIFY_MX_ONLY; /* require MX RRs for MAIL FROM: hosts */
@@ -122,21 +122,6 @@ long resolve_timeout = RESOLVE_TIMEOUT;	/* timeout on directors/routers */
 
 #ifdef HAVE_LIBWRAP
 
-# include <syslog.h>			/* XXX conflicts with stuff in "logs.h" */
-
-# ifndef LIBWRAP_ALLOW_FACILITY
-#  define LIBWRAP_ALLOW_FACILITY	LOG_AUTH
-# endif
-# ifndef LIBWRAP_ALLOW_SEVERITY
-#  define LIBWRAP_ALLOW_SEVERITY	LOG_INFO
-# endif
-# ifndef LIBWRAP_DENY_FACILITY
-#  define LIBWRAP_DENY_FACILITY		LOG_AUTH
-# endif
-# ifndef LIBWRAP_DENY_SEVERITY
-#  define LIBWRAP_DENY_SEVERITY		LOG_WARNING
-# endif
-
 /*
  * These badly named global variables are used by TCP Wrappers libwrap.a and
  * cannot yet be changed in the smail config file.
