@@ -1,5 +1,5 @@
 /*
-#ident	"@(#)smail/src:RELEASE-3_2_0_101:config.h,v 1.57 1997/10/18 14:57:40 woods Exp"
+#ident	"@(#)smail/src:RELEASE-3_2_0_102:config.h,v 1.60 1998/04/11 23:30:16 woods Exp"
  */
 
 /*
@@ -185,15 +185,15 @@
  * sender on errors.  Grades in the range [n-z] will not have anything
  * returned to the sender on errors.
  *
- * The values recognized by many sendmail.cf files are: special-delivery,
- * first-class and junk.  Others are useful mainly for getting mail out
- * of the local machine or for communication with other hosts running
- * smail in a similar configuration.
+ * The values recognized by many sendmail.cf files are: first-class,
+ * special-delivery, list, bulk, and junk.  Others are useful mainly for
+ * getting mail out of the local machine or for communication with other hosts
+ * running smail in a similar configuration.
  *
- * NOTE: This can be set with the config file value "grades"
+ * NOTE:  This can be set with the config file value "grades"
  */
 #ifndef	GRADES
-# define GRADES "special-delivery:9:air-mail:A:first-class:C:bulk:a:junk:n"
+# define GRADES "first-class:0:special-delivery:9:air-mail:A:list:L:bulk:b:occupant:o:junk:z"
 #endif
 
 /*
@@ -1192,7 +1192,7 @@ ${if and{{origin:local} {def:owner}}\
 #if defined(USE_LOCAL_MAIL_COMMAND) && !defined(NO_USE_LOCAL_MAIL_COMMAND)
 # if !defined(LOCAL_MAIL_COMMAND)
 #  if defined(UNIX_BSD4_4) || defined(BSDI)
-#   define LOCAL_MAIL_COMMAND "/usr/libexec/mail.local -f ${shquote:sender} $(${lc:user}$)"
+#   define LOCAL_MAIL_COMMAND "/usr/libexec/mail.local -f ${sender} $(${lc:user}$)"
 #  else
 #   define LOCAL_MAIL_COMMAND "/bin/mail -d $(${lc:user}$)"
 #  endif
@@ -1924,3 +1924,23 @@ ${if and{{origin:local} {def:owner}}\
 #if	!defined(REWRITE_TRYAGAIN) && !defined(NO_REWRITE_TRYAGAIN)
 /* # define REWRITE_TRYAGAIN		(* you probably don't want this! *) */
 #endif
+
+#ifdef HAVE_LIBWRAP
+
+# include <tcpd.h>
+# include <syslog.h>
+
+# ifndef LIBWRAP_ALLOW_FACILITY
+#  define LIBWRAP_ALLOW_FACILITY        LOG_AUTH
+# endif
+# ifndef LIBWRAP_ALLOW_SEVERITY
+#  define LIBWRAP_ALLOW_SEVERITY        LOG_INFO
+# endif
+# ifndef LIBWRAP_DENY_FACILITY
+#  define LIBWRAP_DENY_FACILITY         LOG_AUTH
+# endif
+# ifndef LIBWRAP_DENY_SEVERITY
+#  define LIBWRAP_DENY_SEVERITY         LOG_WARNING
+# endif
+
+#endif /* HAVE_LIBWRAP */
