@@ -1,5 +1,5 @@
 /*
-#ident	"@(#)smail/src:RELEASE-3_2_0_101:default.c,v 1.45 1997/12/16 22:13:38 woods Exp"
+#ident	"@(#)smail/src:RELEASE-3_2_0_102:default.c,v 1.47 1998/01/11 07:03:28 woods Exp"
  */
 
 /*
@@ -994,6 +994,9 @@ static struct transport local_transport = {
  * Run a shell command by piping the message to the shell.  Shell
  * commands can only be produced if the aliasfile and forwardfile
  * drivers are used.
+ *
+ * Note that if the command starts with '$' it will be passed to
+ * expand_string() before it is passed to build_cmd_line().
  */
 static struct pipe_private pipe_transport_priv = {
 #ifdef HAVE_SYS_INTERPRETER	/* NOTE: autoconf has AC_SYS_INTERPRETER but
@@ -1001,7 +1004,8 @@ static struct pipe_private pipe_transport_priv = {
 				 */
     "$user",				/* command is passed as next_addr */
 #else
-    "/bin/sh -c \"$user\"",		/* command is passed as next_addr */
+    /* XXX should use SHELL_EXEC_PATH */
+    "/bin/sh -c ${shquote:user}",	/* command is passed as next_addr */
 #endif
     NULL,				/* use uid of the recipient */
     NULL,				/* use gid of the recipient */
