@@ -1,5 +1,5 @@
 /*
-#ident	"@(#)smail/src:RELEASE-3_2_0_101:direct.c,v 1.22 1997/12/14 05:12:32 woods Exp"
+#ident	"@(#)smail/src:RELEASE-3_2_0_102:direct.c,v 1.23 1998/04/11 23:30:20 woods Exp"
  */
 
 /*
@@ -718,7 +718,7 @@ finish_direct_special_form(addr, dp, form, new, out, defer, fail, includes)
 	if (operation_mode != VERIFY_ADDRS &&
 	    operation_mode != TEST_MODE)
 	{
-	    write_log(LOG_SYS,
+	    write_log(WRITE_LOG_SYS,
 		"%s ... director %s: child of %s insecure, access as 'nobody'",
 		      addr->in_addr,
 		      dp->name,
