@@ -1,5 +1,5 @@
 /*
-#ident	"@(#)smail/src/directors:RELEASE-3_2_0_101:fwdfile.c,v 1.25 1997/06/11 04:15:51 woods Exp"
+#ident	"@(#)smail/src/directors:RELEASE-3_2_0_102:fwdfile.c,v 1.26 1998/04/11 23:31:23 woods Exp"
  */
 
 /*
@@ -532,7 +532,7 @@ finish_forward(dp, addr, new, defer, fail)
 	    STR_NEXT(&fwdtobuf, c);
 	}
 	if (ferror(fp)) {
-	    write_log(LOG_SYS, "read failed on %s, director=%s", fn, dp->name);
+	    write_log(WRITE_LOG_SYS, "read failed on %s, director=%s", fn, dp->name);
 	    (void) fclose(fp);
 	    xfree(fn);
 	    STR_FREE(&fwdtobuf);
@@ -552,7 +552,7 @@ finish_forward(dp, addr, new, defer, fail)
 	buf = xmalloc(statbuf.st_size + 1); /* leave room for trailing nul */
 
 	if (fread(buf, (size_t) statbuf.st_size, 1, fp) < 1) {
-	    write_log(LOG_SYS, "read failed on %s, director=%s", fn, dp->name);
+	    write_log(WRITE_LOG_SYS, "read failed on %s, director=%s", fn, dp->name);
 	    (void) fclose(fp);
 	    xfree(buf);
 	    xfree(fn);
@@ -767,7 +767,7 @@ forward_secure(dp, addr, statp, fn)
 		struct passwd *pw = getpwbyname(temp);
 
 		if (pw == NULL) {
-		    write_log(LOG_SYS, "dtd_forwardfile: no such owner %s\n",
+		    write_log(WRITE_LOG_SYS, "dtd_forwardfile: no such owner %s\n",
 			      temp);
 		} else {
 		    if (statp->st_uid == pw->pw_uid) {
@@ -798,7 +798,7 @@ forward_secure(dp, addr, statp, fn)
 	    struct group *gr = getgrbyname(temp);
 
 	    if (gr == NULL) {
-		write_log(LOG_SYS, "dtd_forwardfile: no such owngroup %s\n",
+		write_log(WRITE_LOG_SYS, "dtd_forwardfile: no such owngroup %s\n",
 			  temp);
 	    } else {
 		if (statp->st_gid == gr->gr_gid) {
