@@ -1,5 +1,5 @@
 /*
-#ident	"@(#)smail/src:RELEASE-3_2_0_101:expand.c,v 1.26 1997/06/25 04:46:37 woods Exp"
+#ident	"@(#)smail/src:RELEASE-3_2_0_102:expand.c,v 1.27 1998/01/09 02:30:01 woods Exp"
  */
 
 /*
@@ -1038,17 +1038,24 @@ substitute(addr, file, found, var, len)
     if (strncmpic(var, "strip:", sizeof("strip:") - 1) == 0) {
 	return strip_fold(substitute(addr, found, file, var + 6, len - 6));
     }
-    if (strncmpic(var, "parent:", sizeof("parent:") - 1) == 0) {
-	struct addr *parent = addr->parent;
-
-	if (parent == NULL) {
+    if (strncmpic(var, "eval:", sizeof("eval:") - 1) == 0) {
+	if (!addr) {			/* expand string would fake it... */
 	    return NULL;
 	}
-	return substitute(parent, found, file, var + 7, len - 7);
+	return expand_string(substitute(addr, found, file, var + 5, len-5), addr, (char *) NULL, (char *) NULL);
+    }
+    if (strncmpic(var, "parent:", sizeof("parent:") - 1) == 0) {
+	if (!addr || !addr->parent) {
+	    return NULL;
+	}
+	return substitute(addr->parent, found, file, var + 7, len - 7);
     }
     if (strncmpic(var, "top:", sizeof("top:") - 1) == 0) {
 	struct addr *top = addr;
 
+	if (!top) {
+	    return NULL;
+	}
 	while (top->parent) {
 	    top = top->parent;
 	}
