@@ -1,5 +1,5 @@
 /*
-#ident	"@(#)smail/src:RELEASE-3_2_0_101:extern.h,v 1.61 1997/12/16 22:11:44 woods Exp"
+#ident	"@(#)smail/src:RELEASE-3_2_0_102:extern.h,v 1.62 1998/02/15 21:12:33 woods Exp"
  */
 
 /*
@@ -97,7 +97,7 @@ extern int smtp_info;			/* allow EXPN/VRFY commands in SMTP */
 extern char *smtp_remote_allow;		/* ip list that can send remote smtp */
 extern char *smtp_local_net;		/* the local network calculated from src. addr */
 extern int smtp_hello_verify;		/* verify HELO/EHLO host has A RR matching sockaddr */
-extern int smtp_hello_broken_allow;	/* ip list that can avoid hello verification */
+extern char *smtp_hello_broken_allow;	/* ip list that can avoid hello verification */
 extern int smtp_hello_verify_literal;	/* verify HELO/EHLO domain literal has PTR RR */
 extern int smtp_hello_verify_ptr;	/* verify HELO/EHLO matches PTR RR for sockaddr */
 extern int smtp_sender_verify_mx_only;	/* require MX RRs for MAIL FROM: hosts */
