@@ -1,5 +1,5 @@
 /*
-#ident	"@(#)smail/src:RELEASE-3_2_0_101:header.c,v 1.30 1997/12/04 01:34:51 woods Exp"
+#ident	"@(#)smail/src:RELEASE-3_2_0_102:header.c,v 1.31 1998/04/11 23:30:23 woods Exp"
  */
 
 /*
@@ -587,7 +587,7 @@ parse_precedence(field)
     error = tokenize(field, &tok, FALSE, TRUE);
     if (error) {
 	/* tokenize didn't like the field for some reason */
-	write_log(LOG_MLOG, "Error in precedence field: %s", error);
+	write_log(WRITE_LOG_MLOG, "Error in precedence field: %s", error);
 	return '\0';			/* no precedence value */
     }
     if (tok->form != T_TEXT) {
@@ -672,7 +672,7 @@ read_header()
 		    c = GETSPOOL();
 	    }
 	    if (c == READ_FAIL) {
-		write_log(LOG_SYS, "read error in spool file <%s/%s>",
+		write_log(WRITE_LOG_SYS, "read error in spool file <%s/%s>",
 			  spool_dir, spool_fn);
 		return FAIL;
 	    }
@@ -700,7 +700,7 @@ read_header()
 	    last_c = c;
 	}
 	if (c == READ_FAIL) {
-	    write_log(LOG_SYS, "read error in spool file <%s/%s>",
+	    write_log(WRITE_LOG_SYS, "read error in spool file <%s/%s>",
 		      spool_dir, spool_fn);
 	}
 
@@ -725,7 +725,7 @@ read_header()
      * message body (after last valid field line)
      */
     if (line_mark >= 0 && seek_spool((off_t) line_mark) == FAIL) {
-	write_log(LOG_SYS, "seek error on spool file <%s/%s>",
+	write_log(WRITE_LOG_SYS, "seek error on spool file <%s/%s>",
 		  spool_dir, spool_fn);
 	return FAIL;
     }
@@ -1013,7 +1013,7 @@ build_strict_header()
 	 * errors will generate a NULL sender path, so nothing will
 	 * be prepended to addresses in recipient fields
 	 */
-	write_log(LOG_MLOG, "error building path to sender <%s>: %s",
+	write_log(WRITE_LOG_MLOG, "error building path to sender <%s>: %s",
 		  sender, error);
     } else {
 	char *p = sender_path + strlen(sender_path);
@@ -1023,7 +1023,7 @@ build_strict_header()
 	 */
 	p = back_address_token(sender_path, p);
 	if (p == NULL) {
-	    write_log(LOG_MLOG,
+	    write_log(WRITE_LOG_MLOG,
 		 "error building path to sender <%s>: unexpected end of token",
 		      sender);
 	    sender_path = NULL;
