@@ -1,5 +1,5 @@
 /*
-#ident	"@(#)smail/src:RELEASE-3_2_0_101:log.c,v 1.22 1997/12/16 22:11:46 woods Exp"
+#ident	"@(#)smail/src:RELEASE-3_2_0_102:log.c,v 1.23 1998/04/11 23:30:26 woods Exp"
  */
 
 /*
@@ -392,7 +392,7 @@ panic(exitcode, fmt, va_alist)
 #else
 	va_start(ap);
 #endif
-	write_log_va(LOG_TTY, fmt, ap);
+	write_log_va(WRITE_LOG_TTY, fmt, ap);
 	va_end(ap);
     }
     /*
@@ -441,12 +441,12 @@ panic(exitcode, fmt, va_alist)
 #else
 	va_start(ap);
 #endif
-	write_log_va(LOG_PANIC, fmt, ap);
+	write_log_va(WRITE_LOG_PANIC, fmt, ap);
 	va_end(ap);
     }
 
     if (daemon_pid != 0 && daemon_pid == getpid()) {
-	write_log(LOG_SYS, "pid: smail daemon exiting on panic");
+	write_log(WRITE_LOG_SYS, "pid: smail daemon exiting on panic");
     }
     if (spool_fn) {
 	defer_message();		/* put message in error/ directory */
@@ -458,13 +458,13 @@ panic(exitcode, fmt, va_alist)
 }
 
 #ifndef NODEBUG
-# define LOG_DEBUG	(LOG_LAST << 2)	/* magic  for write_log_va() */
+# define WRITE_LOG_DEBUG	(WRITE_LOG_LAST << 2) /* magic for write_log_va() */
 #endif
 /*
  * write_log - write to the per-message log, and perhaps the system log
  *
  * write a log message to the various log files, where `who' is the
- * bitwise OR of LOG_SYS, LOG_MLOG and/or LOG_PANIC.
+ * bitwise OR of WRITE_LOG_SYS, WRITE_LOG_MLOG and/or WRITE_LOG_PANIC.
  *
  * Note that messages with a leading 'X' are for per-message logs.
  */
@@ -489,12 +489,12 @@ write_log(who, fmt, va_alist)
 #else
 	va_start(ap);
 #endif
-	write_log_va(LOG_DEBUG, fmt, ap);
+	write_log_va(WRITE_LOG_DEBUG, fmt, ap);
 	va_end(ap);
     }
 #endif
-    if (errfile && ((who & LOG_TTY) ||
-		   ((who & (LOG_MLOG|LOG_PANIC)) &&
+    if (errfile && ((who & WRITE_LOG_TTY) ||
+		   ((who & (WRITE_LOG_MLOG|WRITE_LOG_PANIC)) &&
 		    (error_processing == TERMINAL ||
 		     error_processing == ERROR_DEFAULT) && /* XXX ??? */
 		    fmt[0] != 'X'))) {
@@ -503,34 +503,34 @@ write_log(who, fmt, va_alist)
 #else
 	va_start(ap);
 #endif
-	write_log_va(LOG_TTY, fmt, ap);
+	write_log_va(WRITE_LOG_TTY, fmt, ap);
 	va_end(ap);
     }
-    if (who & LOG_SYS) {
+    if (who & WRITE_LOG_SYS) {
 #ifdef ANSI_C
 	va_start(ap, fmt);
 #else
 	va_start(ap);
 #endif
-	write_log_va(LOG_SYS, fmt, ap);
+	write_log_va(WRITE_LOG_SYS, fmt, ap);
 	va_end(ap);
     }
-    if (who & LOG_PANIC) {
+    if (who & WRITE_LOG_PANIC) {
 #ifdef ANSI_C
 	va_start(ap, fmt);
 #else
 	va_start(ap);
 #endif
-	write_log_va(LOG_PANIC, fmt, ap);
+	write_log_va(WRITE_LOG_PANIC, fmt, ap);
 	va_end(ap);
     }
-    if (who & LOG_MLOG) {
+    if (who & WRITE_LOG_MLOG) {
 #ifdef ANSI_C
 	va_start(ap, fmt);
 #else
 	va_start(ap);
 #endif
-	write_log_va(LOG_MLOG, fmt, ap);
+	write_log_va(WRITE_LOG_MLOG, fmt, ap);
 	va_end(ap);
     }
 }
@@ -543,24 +543,24 @@ write_log_va(who, fmt, ap)
 {
     switch (who) {
 #ifndef NODEBUG
-    case LOG_DEBUG: {
+    case WRITE_LOG_DEBUG: {
 	int wct = 0;
 
 	/* if we are debugging at all, print logging messages */
 	(void) fprintf(errfile, "write_log:");
 
 	/* when debugging, tell which log files are to be used */
-	if (debug > 1 && (who & LOG_SYS)) {
+	if (debug > 1 && (who & WRITE_LOG_SYS)) {
 	    (void) fprintf(errfile, " SYS");
 	    wct++;
 	}
-	if (debug > 1 && (who & LOG_PANIC)) {
+	if (debug > 1 && (who & WRITE_LOG_PANIC)) {
 	    (void) fprintf(errfile, "%cPANIC", wct++? '|': ' ');
 	}
-	if (debug > 1 && (who & LOG_MLOG)) {
+	if (debug > 1 && (who & WRITE_LOG_MLOG)) {
 	    (void) fprintf(errfile, "%cMLOG", wct++? '|': ' ');
 	}
-	if (debug > 1 && (who & LOG_TTY)) {
+	if (debug > 1 && (who & WRITE_LOG_TTY)) {
 	    (void) fprintf(errfile, "%cTTY", wct++? '|': ' ');
 	}
 	if (debug > 1) {
@@ -575,7 +575,7 @@ write_log_va(who, fmt, ap)
 
 #endif	/* NODEBUG */
 
-    case LOG_TTY:
+    case WRITE_LOG_TTY:
     {
 	(void) fprintf(errfile, "%s: ", program);
 	(void) vfprintf(errfile, fmt, ap);
@@ -585,7 +585,7 @@ write_log_va(who, fmt, ap)
     }
     break;
 
-    case LOG_SYS:
+    case WRITE_LOG_SYS:
     {
 	/* write out permanent log to the system log file */
 	if (logfile == NULL || panicfile == NULL) {
@@ -610,7 +610,7 @@ write_log_va(who, fmt, ap)
     }
     break;
 
-    case LOG_PANIC:
+    case WRITE_LOG_PANIC:
     {
 	if (panicfile == NULL) {
 	    open_system_logs();		/* if system log not open, open it */
@@ -640,7 +640,7 @@ write_log_va(who, fmt, ap)
      *	      cannot be created, so don't bother writing per-message
      *	      log entries.
      */
-    case LOG_MLOG:
+    case WRITE_LOG_MLOG:
 	if (spool_dir) {
 	    if (msg_logfile == NULL) {
 		open_msg_log();		/* if message log not open, open it */
@@ -831,15 +831,15 @@ main()
 	    break;
 	case 'l':
 	    fgets(line, sizeof(line), stdin);
-	    write_log(LOG_SYS, line);
+	    write_log(WRITE_LOG_SYS, line);
 	    break;
 	case 'm':
 	    fgets(line, sizeof(line), stdin);
-	    write_log(LOG_MLOG, line);
+	    write_log(WRITE_LOG_MLOG, line);
 	    break;
 	case 'L':
 	    fgets(line, sizeof(line), stdin);
-	    write_log(LOG_MLOG|LOG_SYS|LOG_PANIC);
+	    write_log(WRITE_LOG_MLOG|WRITE_LOG_SYS|WRITE_LOG_PANIC);
 	    break;
 	case ' ':
 	case '\t':
