@@ -1,5 +1,5 @@
 /*
-#ident	"@(#)smail/src:RELEASE-3_2_0_101:main.c,v 1.45 1997/12/16 22:11:49 woods Exp"
+#ident	"@(#)smail/src:RELEASE-3_2_0_102:main.c,v 1.48 1998/04/13 03:33:39 woods Exp"
  */
 
 /*
@@ -202,7 +202,7 @@ main(argc, argv)
 
 	if (setgroups(0, (gid_t *) NULL) != 0) {
 	    if (setgroups(1, dummy_grouplist) != 0) {
-		write_log(LOG_TTY | ((geteuid() == 0) ? LOG_PANIC : 0),
+		write_log(WRITE_LOG_TTY | ((geteuid() == 0) ? WRITE_LOG_PANIC : 0),
 			  "setgroups() failed: %s", strerror(errno));
 	    }
 	}
@@ -462,11 +462,11 @@ main(argc, argv)
 	case DELIVER_MAIL:
 	case PRINT_VARS_MODE:
 	case REBUILD_ALIASES:
-	    write_log(LOG_TTY|LOG_PANIC, "%s", error);
+	    write_log(WRITE_LOG_TTY|WRITE_LOG_PANIC, "%s", error);
 	    break;
 
 	default:
-	    write_log(LOG_TTY|LOG_PANIC, "%s", error);
+	    write_log(WRITE_LOG_TTY|WRITE_LOG_PANIC, "%s", error);
 	    exit(EX_OSFILE);
 	    /*NOTREACHED*/
 	}
@@ -487,7 +487,7 @@ main(argc, argv)
 	 * stat our binary so we can see if it has been touched later
 	 */
 	if (stat(smail, &statbuf) < 0) {
-	    write_log(LOG_TTY|LOG_PANIC, "main: bad stat() of smail binary %s", smail);
+	    write_log(WRITE_LOG_TTY|WRITE_LOG_PANIC, "main: bad stat() of smail binary %s", smail);
 	    exit(EX_SOFTWARE);
 	    /* NOTREACHED */
 	} else {
@@ -506,7 +506,7 @@ main(argc, argv)
 	    (error = read_qualify_file()) ||
 	    (error = read_retry_file()))
 	{
-	    write_log(LOG_TTY|LOG_PANIC, "%s", error);
+	    write_log(WRITE_LOG_TTY|WRITE_LOG_PANIC, "%s", error);
 	    exit(EX_OSFILE);
 	    /* NOTREACHED */
 	}
@@ -569,7 +569,7 @@ main(argc, argv)
 
     if (arg_debug_file) {
 	if (!(new_errfile = fopen_as_user(arg_debug_file, "a", real_uid, (int) getgid(), 0600))) {
-	    write_log(LOG_TTY, "Warning: Cannot open debug file %s: %s\n",
+	    write_log(WRITE_LOG_TTY, "Warning: Cannot open debug file %s: %s\n",
 		      arg_debug_file, strerror(errno));
 	    arg_debug_file = NULL;
 	} else {
@@ -743,14 +743,21 @@ main(argc, argv)
 #endif
 	utilargs[1] = xprintf("%s/mkaliases", smail_util_dir);
 	utilargs[2] = NULL;
-	if (arg_alias_file) {
-	    utilargs[2] = arg_alias_file;
-	    utilargs[3] = NULL;
+	utilargs[3] = NULL;
+	utilargs[4] = NULL;
+	if (debug) {
+	    static char debug_arg[30];	/* space for max int digits (2^(CHAR_BIT * sizeof(int)) = 10^digits) */
+
+	    sprintf(debug_arg, "-v %d", debug);
+	    utilargs[2] = debug_arg;
 	}
-	DEBUG3(DBG_MAIN_LO, "main: about to run %s %s %s\n",
-	       utilargs[0], utilargs[1], utilargs[2] ? utilargs[2] : "");
-	child = open_child(utilargs, (char **) NULL, (FILE **) NULL, (FILE **) NULL,
-			   -1, CHILD_MINENV, (int) getuid(), (int) getgid());
+	if (arg_alias_file) {
+	    utilargs[utilargs[2] ? 3 : 2] = arg_alias_file;
+	}
+	DEBUG4(DBG_MAIN_LO, "main: about to run %s %s %s %s\n",
+	       utilargs[0], utilargs[1], utilargs[2] ? utilargs[2] : "", utilargs[3] ? utilargs[3] : "");
+	child = open_child(utilargs, (char **) NULL, stdin, stdout, fileno(stderr),
+			   CHILD_MINENV, (int) getuid(), (int) getgid());
 	if (child == -1) {
 	    if (errfile) {
 		fprintf(errfile, "%s: Cannot start %s: %s\n",
@@ -879,6 +886,9 @@ process_args(args)
 		break;
 
 	    case 'D':
+		if (prog_type == PROG_RMAIL || prog_type == PROG_RSMTP) {
+		    rmail_panic();
+		}
 		arg_debug_file = arg;
 		arg = end_arg;
 		if (arg_debug_file[0] == '\0') {
@@ -894,6 +904,9 @@ process_args(args)
 		break;
 
 	    case 'F':			/* set full name of sender */
+		if (prog_type == PROG_RMAIL || prog_type == PROG_RSMTP) {
+		    rmail_panic();
+		}
 		sender_name = arg;
 		arg = end_arg;		/* terminate args in current argv */
 		/* if no string there, take next arg */
@@ -910,6 +923,9 @@ process_args(args)
 		/* FALLTHRU */
 
 	    case 'f':			/* set path to sender */
+		if (prog_type == PROG_RMAIL || prog_type == PROG_RSMTP) {
+		    rmail_panic();
+		}
 		newsender = arg;
 		arg = end_arg;		/* terminate args in current argv */
 		/* if no string there, take next arg */
@@ -1093,6 +1109,9 @@ process_args(args)
 		switch (*arg++) {
 
 		case 'A':
+		    if (prog_type == PROG_RMAIL || prog_type == PROG_RSMTP) {
+			rmail_panic();
+		    }
 		    if (*arg == '\0') {
 			arg = *args++;
 			panic_if_null(arg, "oA");
@@ -1157,6 +1176,9 @@ process_args(args)
 		    break;
 
 		case 'M':
+		    if (prog_type == PROG_RMAIL || prog_type == PROG_RSMTP) {
+			rmail_panic();
+		    }
 		    if (*arg == '\0') {
 			arg = *args++;
 			panic_if_null(arg, "oM");
@@ -1275,6 +1297,9 @@ process_args(args)
 #endif
 
 		case 'X':
+		    if (prog_type == PROG_RMAIL || prog_type == PROG_RSMTP) {
+			rmail_panic();
+		    }
 		    if (*arg == '\0') {
 			arg = *args++;
 			panic_if_null(arg, "oX");
@@ -1410,6 +1435,9 @@ process_args(args)
 		    break;
 
 		case 'P':
+		    if (prog_type == PROG_RMAIL || prog_type == PROG_RSMTP) {
+			rmail_panic();
+		    }
 		    operation_mode = PRINT_VARS_MODE;
 		    break;
 		}
