@@ -1,5 +1,5 @@
 /*
-#ident	"@(#)smail/src:RELEASE-3_2_0_101:modes.c,v 1.73 1997/12/16 22:11:53 woods Exp"
+#ident	"@(#)smail/src:RELEASE-3_2_0_102:modes.c,v 1.75 1998/04/11 23:30:35 woods Exp"
  */
 
 /*
@@ -134,8 +134,6 @@
 
 #ifdef HAVE_LIBWRAP
 
-# include <tcpd.h>  
-
 int smtp_session_denied = 0;		/* used in smtprecv.c */
 
 #endif /* HAVE_LIBWRAP */
@@ -379,7 +377,7 @@ sig_unlink(sig)
 {
     (void) signal(sig, SIG_IGN);
     unlink_spool();
-    write_log(LOG_TTY, "interrupt: mail message removed");
+    write_log(WRITE_LOG_TTY, "interrupt: mail message removed");
     exit(EX_OSERR);
 }
 
@@ -453,7 +451,7 @@ test_addresses()
 
 	cur->in_addr = lp;
 	if ((cur->work_addr = preparse_address(lp, &error)) == NULL) {
-	    write_log(LOG_TTY, "syntax error in address: %s", error);
+	    write_log(WRITE_LOG_TTY, "syntax error in address: %s", error);
 	    continue;
 	}
 
@@ -623,7 +621,7 @@ perform_deliver_mail()
 	pid = fork();
 	if (pid < 0) {
 	    /* fork failed, just leave the queue file there and exit */
-	    write_log(LOG_TTY, "fork failed: %s, message queued", strerror(errno));
+	    write_log(WRITE_LOG_TTY, "fork failed: %s, message queued", strerror(errno));
 	    close_spool();
 	    return;
 	}
@@ -767,7 +765,7 @@ deliver_mail()
 	error = process_header((struct addr **)NULL);
     }
     if (error) {
-	write_log(LOG_MLOG, "error in header: %s", error);
+	write_log(WRITE_LOG_MLOG, "error in header: %s", error);
 	if (extract_addresses) {
 	    return_to_sender = TRUE;
 	    /* notify people of errors, ignoring previously reported errors */
@@ -793,7 +791,7 @@ deliver_mail()
     resolve_addr_list(route_list, &deliver, &defer, &fail, TRUE);
 
     if (deliver == NULL && defer == NULL) {
-	write_log(LOG_MLOG, "no valid recipients were found for this message");
+	write_log(WRITE_LOG_MLOG, "no valid recipients were found for this message");
 	return_to_sender = TRUE;
     }
 
@@ -870,7 +868,7 @@ deliver_mail()
 	 * occured, then we are done with the message.  Thus, unlink
 	 * the message and the per-message log file.
 	 */
-	write_log(LOG_SYS, "Completed.");
+	write_log(WRITE_LOG_SYS, "Completed.");
 	unlink_spool();
 	unlink_msg_log();
     }
@@ -940,7 +938,7 @@ daemon_mode()
 	port = htons(atoi(smtp_service_name));
     } else {
 	if ((smtp_service = getservbyname(smtp_service_name, "tcp")) == NULL) {
-	    write_log(LOG_SYS, "%s/tcp: unknown service", smtp_service_name);
+	    write_log(WRITE_LOG_SYS, "%s/tcp: unknown service", smtp_service_name);
 	    exitvalue = EX_UNAVAILABLE;
 	    return;
 	}
@@ -949,7 +947,7 @@ daemon_mode()
     (void) bzero((char *)&sin, sizeof(sin));
     ls = socket(AF_INET, SOCK_STREAM, 0);
     if (ls < 0) {
-	write_log(LOG_SYS, "socket(AF_INET, SOCKSTREAM, 0) failed: %s",
+	write_log(WRITE_LOG_SYS, "socket(AF_INET, SOCKSTREAM, 0) failed: %s",
 		  strerror(errno));
 	exitvalue = EX_OSERR;
 	return;
@@ -980,13 +978,13 @@ daemon_mode()
 
     /* XXX: optval argument is (const char *) on Solaris-2 and (void *) in Net/3 */
     if (setsockopt(ls, SOL_SOCKET, SO_REUSEADDR, (char *)&optval, sizeof(optval)) < 0) {
-	write_log(LOG_SYS, "SO_REUSEADDR on failed: %s\n", strerror(errno));
+	write_log(WRITE_LOG_SYS, "SO_REUSEADDR on failed: %s\n", strerror(errno));
 	exitvalue = EX_OSERR;
 	return;
     }
 
     if (bind(ls, (struct sockaddr *)&sin, sizeof(sin)) < 0) {
-	write_log(LOG_SYS, "bind() failed: %s", strerror(errno));
+	write_log(WRITE_LOG_SYS, "bind() failed: %s", strerror(errno));
 	exitvalue = EX_OSERR;
 	return;
     }
@@ -1086,7 +1084,7 @@ daemon_mode()
 	nsel = select(ls + 1, &fds_read, (char *)0, (char *)0, (char *)0);
 	if (nsel < 0) {
 	    if (errno != EINTR) {
-		write_log(LOG_PANIC, "select failed: %s", strerror(errno));
+		write_log(WRITE_LOG_PANIC, "select failed: %s", strerror(errno));
 		continue;
 	    }
 	} else {
@@ -1095,20 +1093,23 @@ daemon_mode()
 	/* get connection */
 	as = accept(ls, (struct sockaddr *)&from, &len);
 	if (as < 0 && errno != EINTR) {
-	    write_log(LOG_PANIC, "accept failed: %s", strerror(errno));
+	    unsigned int oldalarm;
+
+	    write_log(WRITE_LOG_PANIC, "accept failed: %s", strerror(errno));
 
 	    /*
 	     * for some reason, accept() fails badly (and repeatedly)
 	     * on some systems.  To prevent the paniclog from filling
 	     * up, exit if this happens too many times.
 	     */
-
+	    oldalarm = alarm(0);	/* pause alarm during this sleep() */
 	    sleep(5);
 	    accept_err_cnt++;
 	    if (accept_err_cnt == 10) {
-		    write_log(LOG_PANIC, "too many accept errors, quitting");
+		    write_log(WRITE_LOG_PANIC, "too many accept errors, quitting");
 		    exit(EX_OSERR);
 	    }
+	    alarm(oldalarm);		/* reset alarm */
 	    continue;
 	}
 	accept_err_cnt = 0;
@@ -1137,7 +1138,7 @@ daemon_mode()
 #endif
 
 	if (got_sighup) {
-	    write_log(LOG_SYS, "pid %d: SIGHUP received, exec(%s)",
+	    write_log(WRITE_LOG_SYS, "pid %d: SIGHUP received, exec(%s)",
 		      getpid(), smail);
 	    execv(smail, save_argv);
 	    panic(EX_UNAVAILABLE, "pid %d: exec of %s failed", getpid(), smail);
@@ -1147,7 +1148,7 @@ daemon_mode()
 	    DEBUG(DBG_MAIN_LO, "SIGALRM received, check input queue\n");
 	    if (is_newconf()) {
 		/* re-exec smail */
-		write_log(LOG_SYS, "pid %d: new config files, exec(%s)",
+		write_log(WRITE_LOG_SYS, "pid %d: new config files, exec(%s)",
 			  getpid(), smail);
 		execv(smail, save_argv);
 		panic(EX_UNAVAILABLE, "pid %d: exec of %s failed", getpid(), smail);
@@ -1203,7 +1204,7 @@ do_daemon_accept(ls, fd, from)
 
 	    (void) close(fd);
 	    /* XXX this may still fail if the paniclog wasn't open already */
-	    write_log(LOG_PANIC, "fdopen() failed trying to write 421 to client [%s]: %s.",
+	    write_log(WRITE_LOG_PANIC, "fdopen() failed trying to write 421 to client [%s]: %s.",
 		      inet_ntoa(from->sin_addr), strerror(sverrno2));
 	    return;
 	}
@@ -1221,7 +1222,7 @@ do_daemon_accept(ls, fd, from)
 
 	DEBUG3(DBG_MAIN_MID, "fork() failed for pid %d: rejecting SMTP connection #%d: %s\n",
 	       getpid(), smtp_accept_count + 1, strerror(oerrno));
-	write_log(LOG_SYS, "pid %d: fork() failed: %s", getpid(), strerror(oerrno));
+	write_log(WRITE_LOG_SYS, "pid %d: fork() failed: %s", getpid(), strerror(oerrno));
 	(void) fprintf(f, "421 %s Connection refused -- system resources exausted\r\n",
 		       primary_name);
 	(void) fflush(f);
@@ -1327,7 +1328,7 @@ static void
 daemon_sigterm(sig)
     int sig;
 {
-    write_log(LOG_SYS, "pid %d: SIGTERM received, shutting down daemon.", getpid());
+    write_log(WRITE_LOG_SYS, "pid %d: SIGTERM received, shutting down daemon.", getpid());
     exit(EX_OK);
 }
 
@@ -1441,7 +1442,7 @@ noop_mode()
 	    pause();
 	    /* watch for SIGHUP to indicate a recycle */
 	    if (got_sighup) {
-		write_log(LOG_SYS, "pid %d: SIGHUP received, exec(%s)",
+		write_log(WRITE_LOG_SYS, "pid %d: SIGHUP received, exec(%s)",
 		       getpid(), smail);
 		execv(smail, save_argv);
 		panic(EX_UNAVAILABLE, "pid %d: exec of %s failed", getpid(), smail);
@@ -1456,7 +1457,7 @@ noop_mode()
 
 	    /* if config file have changed, recycle */
 	    if (is_newconf()) {
-		write_log(LOG_SYS, "pid %d: new config files, exec(%s)",
+		write_log(WRITE_LOG_SYS, "pid %d: new config files, exec(%s)",
 		       getpid(), smail);
 		execv(smail, save_argv);
 		panic(EX_UNAVAILABLE, "pid %d: exec of %s failed", getpid(), smail);
@@ -1513,7 +1514,7 @@ start_daemon()
     if (debug == 0) {
 	pid = fork();
 	if (pid < 0) {
-	    write_log(LOG_TTY, "fork() failed: %s", strerror(errno));
+	    write_log(WRITE_LOG_TTY, "fork() failed: %s", strerror(errno));
 	    exitvalue = EX_OSERR;
 	    return pid;
 	}
@@ -1550,7 +1551,7 @@ start_daemon()
 
     if (queue_interval > 0) {
 	daemon_pid = getpid();
-	write_log(LOG_SYS, "pid %d: smail daemon started", daemon_pid);
+	write_log(WRITE_LOG_SYS, "pid %d: smail daemon started", daemon_pid);
     }
 
     /* grab the real uid under which smail was executed */
@@ -1845,9 +1846,9 @@ print_queue()
 	char *error;
 
 	/* open without locking */
-	if (open_spool(*work, FALSE, LOG_TTY) == FAIL) {
+	if (open_spool(*work, FALSE, WRITE_LOG_TTY) == FAIL) {
 	    if (exitvalue == EX_TEMPFAIL || exitvalue == EX_NOINPUT) {
-		write_log(LOG_TTY|LOG_SYS,
+		write_log(WRITE_LOG_TTY|WRITE_LOG_SYS,
 			  "print_queue: %s/%s: lock failed (this can't happen -- we didn't ask to lock): %s",
 			  spool_dir, input_spool_fn,
 			  exitvalue == EX_TEMPFAIL ? "locked" : "not found");
@@ -2086,7 +2087,7 @@ process_spool_file(spfn)
      * Verify the spool file exists before we try to process it
      */
     if (stat(spfn, &statbuf) < 0) {
-	write_log(LOG_SYS, "process_spool_file: %s: File possibly already processed: %s",
+	write_log(WRITE_LOG_SYS, "process_spool_file: %s: File possibly already processed: %s",
 		  spfn, strerror(errno));
 	return FAIL;
     }
@@ -2115,10 +2116,10 @@ process_spool_file(spfn)
 	initialize_state();
 
 	/* in child process, open the message and attempt delivery */
-	if (open_spool(spfn, TRUE, LOG_SYS) == FAIL) {
+	if (open_spool(spfn, TRUE, WRITE_LOG_SYS) == FAIL) {
 	    if (exitvalue == EX_TEMPFAIL || exitvalue == EX_NOINPUT) {
 		/* XXX in theory this should be just a DEBUG() */
-		write_log(LOG_TTY|LOG_SYS,
+		write_log(WRITE_LOG_TTY|WRITE_LOG_SYS,
 			  "process_spool_file: %s/%s: file %s",
 			  spool_dir, input_spool_fn,
 			  (exitvalue == EX_TEMPFAIL) ? "already locked; skipping"
