@@ -1,5 +1,5 @@
 /*
-#ident	"@(#)smail/src:RELEASE-3_2_0_101:notify.c,v 1.29 1997/09/22 23:31:55 woods Exp"
+#ident	"@(#)smail/src:RELEASE-3_2_0_102:notify.c,v 1.30 1998/04/11 23:30:39 woods Exp"
  */
 
 /*
@@ -83,7 +83,7 @@ fail_delivery(addr)
 #if (SMAIL_LOG_STYLE == 2)
 	/* Default new log style (as of 3.1.29) */
 	/* This is SMAIL_LOG_STYLE=2 */
-	write_log(LOG_SYS,
+	write_log(WRITE_LOG_SYS,
 		  "Failed TO:%s%s%s%s%s%s%s ERROR:(ERR%03ld) %s",
 		  cur->in_addr,		/* XXX this is never complete for multi-delivery msgs */
 		  cur->router? " ROUTER:": "",
@@ -98,7 +98,7 @@ fail_delivery(addr)
 # if (!defined(SMAIL_LOG_STYLE)) || (SMAIL_LOG_STYLE == 1)
     /* Old log style (as used by 3.1.28) */
     /* This is SMAIL_LOG_STYLE=1 */
-	write_log(LOG_SYS,
+	write_log(WRITE_LOG_SYS,
 		  "%s ... failed: (ERR_%03ld) %s",
 		  cur->in_addr,
 		  cur->error->info & ERR_MASK,
@@ -109,14 +109,14 @@ fail_delivery(addr)
 #endif
 	/* X entries in msg log will be picked up by queue run scans */
 	if (cur->parent) {
-	    write_log(LOG_MLOG,
+	    write_log(WRITE_LOG_MLOG,
 		      "Xfail: <%s> parent: <%s> reason: (ERR%03ld) %s",
 		      cur->in_addr,	/* XXX this is never complete for multi-delivery msgs */
 		      cur->parent->in_addr,
 		      cur->error->info & ERR_MASK,
 		      cur->error->message);
 	} else {
-	    write_log(LOG_MLOG,
+	    write_log(WRITE_LOG_MLOG,
 		      "Xfail: <%s> reason: (ERR%03ld) %s",
 		      cur->in_addr,	/* XXX this is never complete for multi-delivery msgs */
 		      cur->error->info & ERR_MASK,
@@ -182,7 +182,7 @@ defer_delivery(addr, defer_errors)
 #if (SMAIL_LOG_STYLE == 2)
 	/* Default new log style (as of 3.1.29) */
 	/* This is SMAIL_LOG_STYLE=2 */
-	write_log((cur->error->info & ERR_CONFERR)? (LOG_SYS|LOG_TTY): LOG_SYS,
+	write_log((cur->error->info & ERR_CONFERR)? (WRITE_LOG_SYS|WRITE_LOG_TTY): WRITE_LOG_SYS,
 		  "Deferred TO:%s%s%s%s%s%s%s ERROR:(ERR%03ld) %s",
 		  cur->in_addr,		/* XXX this is never complete for multi-delivery msgs */
 		  cur->router? " ROUTER:": "",
@@ -197,7 +197,7 @@ defer_delivery(addr, defer_errors)
 # if (!defined(SMAIL_LOG_STYLE)) || (SMAIL_LOG_STYLE == 1)
     /* Old log style (as used by 3.1.28) */
     /* This is SMAIL_LOG_STYLE=1 */
-	write_log((cur->error->info & ERR_CONFERR)? (LOG_SYS|LOG_TTY): LOG_SYS,
+	write_log((cur->error->info & ERR_CONFERR)? (WRITE_LOG_SYS|WRITE_LOG_TTY): WRITE_LOG_SYS,
                   "%s ... deferred: (ERR_%03ld) %s",
                   cur->in_addr,
                   cur->error->info & ERR_MASK,
@@ -207,14 +207,14 @@ defer_delivery(addr, defer_errors)
 # endif
 #endif
 	if (cur->parent) {
-	    write_log(LOG_MLOG,
+	    write_log(WRITE_LOG_MLOG,
 		      "Xdefer: %s parent: %s reason: (ERR%03ld) %s",
 		      cur->in_addr,	/* XXX this is never complete for multi-delivery msgs */
 		      cur->parent->in_addr,
 		      cur->error->info & ERR_MASK,
 		      cur->error->message);
 	} else {
-	    write_log(LOG_MLOG,
+	    write_log(WRITE_LOG_MLOG,
 		      "Xdefer: %s reason: (ERR%03ld) %s",
 		      cur->in_addr,	/* XXX this is never complete for multi-delivery msgs */
 		      cur->error->info & ERR_MASK,
@@ -238,21 +238,21 @@ succeed_delivery(addr)
 	for (top = cur; top->parent; top = top->parent);
 
 	if (dont_deliver) {
-	    write_log(LOG_SYS, "Debugging: don't deliver %s",
+	    write_log(WRITE_LOG_SYS, "Debugging: don't deliver %s",
 		      top->in_addr);
 	} else {
 #if (SMAIL_LOG_STYLE == 2)
 	    /* Default new log style (as of 3.1.29) */
 	    /* This is SMAIL_LOG_STYLE=2 */
 	    if (cur->next_host) {
-		write_log(LOG_SYS, "Delivered%s%s%s%s%s%s%s%s%s%s",
+		write_log(WRITE_LOG_SYS, "Delivered%s%s%s%s%s%s%s%s%s%s",
 			  " VIA:", cur->next_host,
 			  " TO:", cur->next_addr,
 			  " ORIG-TO:", top->in_addr,
 			  " ROUTER:", cur->router->name,
 			  " TRANSPORT:", cur->transport->name);
 	    } else {
-		write_log(LOG_SYS, "Delivered%s%s%s%s%s%s%s%s",
+		write_log(WRITE_LOG_SYS, "Delivered%s%s%s%s%s%s%s%s",
 			  " TO:", cur->next_addr,
 			  " ORIG-TO:", top->in_addr,
 			  " DIRECTOR:", cur->director->name,
@@ -263,14 +263,14 @@ succeed_delivery(addr)
 	    /* Old log style (as used by 3.1.28) */
 	    /* This is SMAIL_LOG_STYLE=1 */
 	    if (cur->next_host) {
-		write_log(LOG_SYS, "delivered%s%s%s%s%s%s%s%s%s%s",
+		write_log(WRITE_LOG_SYS, "delivered%s%s%s%s%s%s%s%s%s%s",
 			  "\n|\t      via: ", cur->next_host,
                           "\n|\t       to: ", cur->next_addr,
                           "\n|\t  orig-to: ", top->in_addr,
                           "\n|\t   router: ", cur->router->name,
                           "\n|\ttransport: ", cur->transport->name);
 	    } else {
-                write_log(LOG_SYS, "delivered%s%s%s%s%s%s%s%s",
+                write_log(WRITE_LOG_SYS, "delivered%s%s%s%s%s%s%s%s",
                           "\n|\t       to: ", cur->next_addr,
                           "\n|\t  orig-to: ", top->in_addr,
                           "\n|\t director: ", cur->director->name,
@@ -284,10 +284,10 @@ succeed_delivery(addr)
 	}
 	/* X entries will be picked up by queue run scans */
 	if (cur->parent) {
-	    write_log(LOG_MLOG, "Xsucceed: <%s> parent: <%s>",
+	    write_log(WRITE_LOG_MLOG, "Xsucceed: <%s> parent: <%s>",
 		      cur->in_addr, cur->parent->in_addr);
 	} else {
-	    write_log(LOG_MLOG, "Xsucceed: <%s>", cur->in_addr);
+	    write_log(WRITE_LOG_MLOG, "Xsucceed: <%s>", cur->in_addr);
 	}
     }
 }
@@ -310,16 +310,16 @@ error_delivery(addr)
 	/* This is SMAIL_LOG_STYLE=2 */
 	if (cur->true_addr) {
 	    log_addr = cur->true_addr;
-	    write_log(LOG_SYS, "Error sent FOR:%s TO:%s",
+	    write_log(WRITE_LOG_SYS, "Error sent FOR:%s TO:%s",
 		      log_addr->in_addr,
 		      cur->in_addr);	/* XXX ??? */
 	} else {
 	    if (cur->error->info & ERR_NSENDER) {
-		write_log(LOG_SYS, "Returned error FOR:%s TO:%s",
+		write_log(WRITE_LOG_SYS, "Returned error FOR:%s TO:%s",
 			  cur->in_addr, sender);
 	    }
 	    if (cur->error->info & ERR_NPOSTMAST) {
-		write_log(LOG_SYS, "Sent error FOR:%s TO:postmaster",
+		write_log(WRITE_LOG_SYS, "Sent error FOR:%s TO:postmaster",
 			  cur->in_addr);
 	    }
 	}
@@ -329,15 +329,15 @@ error_delivery(addr)
 	/* This is SMAIL_LOG_STYLE=1 */
 	if (cur->true_addr) {
 	    log_addr = cur->true_addr;
-	    write_log(LOG_SYS, "%s ... error sent to %s",
+	    write_log(WRITE_LOG_SYS, "%s ... error sent to %s",
 		      log_addr->in_addr, cur->in_addr);
 	} else {
 	    if (cur->error->info & ERR_NSENDER) {
-		write_log(LOG_SYS, "%s ... error returned to %s",
+		write_log(WRITE_LOG_SYS, "%s ... error returned to %s",
 			  cur->in_addr, sender);
 	    }
 	    if (cur->error->info & ERR_NPOSTMAST) {
-		write_log(LOG_SYS, "%s ... error sent to postmaster",
+		write_log(WRITE_LOG_SYS, "%s ... error sent to postmaster",
 			  cur->in_addr);
 	    }
 	}
@@ -347,10 +347,10 @@ error_delivery(addr)
 #endif
 	/* X entries will be picked up by queue run scans */
 	if (cur->parent) {
-	    write_log(LOG_MLOG, "Xsent_error: <%s> parent: <%s>",
+	    write_log(WRITE_LOG_MLOG, "Xsent_error: <%s> parent: <%s>",
 		      cur->in_addr, cur->parent->in_addr);
 	} else {
-	    write_log(LOG_MLOG, "Xsent_error: <%s>", cur->in_addr);
+	    write_log(WRITE_LOG_MLOG, "Xsent_error: <%s>", cur->in_addr);
 	}
     }
 }
