@@ -1,5 +1,5 @@
 /*
-#ident	"@(#)smail/src:RELEASE-3_2_0_101:queue.c,v 1.36 1997/12/04 01:34:55 woods Exp"
+#ident	"@(#)smail/src:RELEASE-3_2_0_102:queue.c,v 1.37 1998/04/11 23:30:43 woods Exp"
  */
 
 /*
@@ -639,12 +639,12 @@ read_message()
 	(void) sscanf(p2, "%d %d", &real_uid, &prog_egid);
     }
     if (c == READ_FAIL) {
-	write_log(LOG_SYS|LOG_PANIC, "read failed: %s/%s: %s",
+	write_log(WRITE_LOG_SYS|WRITE_LOG_PANIC, "read failed: %s/%s: %s",
 		  spool_dir, input_spool_fn, strerror(errno));
 	return NULL;
     }
     if (c == EOF) {
-	write_log(LOG_SYS, "unexpected end of file: %s/%s",
+	write_log(WRITE_LOG_SYS, "unexpected end of file: %s/%s",
 		  spool_dir, input_spool_fn);
     }
 
@@ -722,13 +722,13 @@ read_message()
 		c = GETSPOOL();
 		if (c == EOF) {
 		    STR_FREE(sp);
-		    write_log(LOG_SYS, "unexpected end of file: %s/%s",
+		    write_log(WRITE_LOG_SYS, "unexpected end of file: %s/%s",
 			      spool_dir, input_spool_fn);
 		    return NULL;	/* no message */
 		} else if (c == 'n') {
 		    c = '\n';
 		} else if (c != '\\') {
-		    write_log(LOG_SYS, "format error in: %s/%s",
+		    write_log(WRITE_LOG_SYS, "format error in: %s/%s",
 			      spool_dir, input_spool_fn);
 		    return NULL;	/* format error */
 		}
@@ -844,7 +844,7 @@ read_from_lines()
 	    STR_NEXT(line, c);
 	}
 	if (c == READ_FAIL) {
-	    write_log(LOG_SYS, "read failed: %s/%s: %s",
+	    write_log(WRITE_LOG_SYS, "read failed: %s/%s: %s",
 		      spool_dir, input_spool_fn, strerror(errno));
 	}
 	if (c != EOF) {
@@ -935,7 +935,7 @@ read_from_lines()
      * a From_ line
      */
     if (seek_spool((off_t) line_mark) == FAIL) {
-	write_log(LOG_SYS, "seek failed on: %s/%s: %s",
+	write_log(WRITE_LOG_SYS, "seek failed on: %s/%s: %s",
 		  spool_dir, input_spool_fn, strerror(errno));
 	return FAIL;
     }
@@ -1040,14 +1040,14 @@ finish_sender(path, user)
 	/*
 	 * failed to parse user, store an error for logging later
 	 */
-	write_log(LOG_MLOG|LOG_SYS, "Error reading sender: %s", remainder);
+	write_log(WRITE_LOG_MLOG|WRITE_LOG_SYS, "Error reading sender: %s", remainder);
 	sender = COPY_STRING("Postmaster");
     } else if (form == LOCAL && path[0] == '\0' && !islocal) {
 	/*
 	 * message was flagged as non-local, but we no longer have any
 	 * host information, send it to the postmaster
 	 */
-	write_log(LOG_MLOG|LOG_SYS, "Path to sender unknown:  sender = %s",
+	write_log(WRITE_LOG_MLOG|WRITE_LOG_SYS, "Path to sender unknown:  sender = %s",
 		  user);
 	sender = COPY_STRING("Postmaster");
     } else if (path[0] == '\0' && form == LOCAL) {
@@ -1079,7 +1079,7 @@ finish_sender(path, user)
 
 	if (route == NULL) {
 	    /* found an error building the route */
-	    write_log(LOG_MLOG|LOG_SYS, "Error building sender: %s", error);
+	    write_log(WRITE_LOG_MLOG|WRITE_LOG_SYS, "Error building sender: %s", error);
 	} else if (path[0] == '\0') {
 	    /*
 	     * no path, just put the user back together
@@ -1109,7 +1109,7 @@ write_body(f, flags)
     long flags;				/* transport flags */
 {
     if (seek_spool((off_t) start_msg) == FAIL) {
-	write_log(LOG_SYS, "seek failed: %s/%s: %s",
+	write_log(WRITE_LOG_SYS, "seek failed: %s/%s: %s",
 		  spool_dir, input_spool_fn, strerror(errno));
 	return READ_FAIL;
     }
@@ -1222,7 +1222,7 @@ log_incoming()
 #if (SMAIL_LOG_STYLE == 2)
     /* Default new log style (as of 3.1.29) */
     /* This is SMAIL_LOG_STYLE=2 */
-    write_log(LOG_SYS, "Received%s%s%s%s%s%s%s%s%s%s%s%ld%s%s%s%s",
+    write_log(WRITE_LOG_SYS, "Received%s%s%s%s%s%s%s%s%s%s%s%ld%s%s%s%s",
 	      " FROM:", sender,
 	      host_string? " HOST:": "", host_string? host_string: "",
 	      sender_proto? " PROTOCOL:": "", sender_proto? sender_proto: "",
@@ -1235,7 +1235,7 @@ log_incoming()
 # if (!defined(SMAIL_LOG_STYLE)) || (SMAIL_LOG_STYLE == 1)
     /* Old log style (as used by 3.1.28) */
     /* This is SMAIL_LOG_STYLE=1 */
-    write_log(LOG_SYS, "received%s%s%s%s%s%s%s%s%s%s%s%ld%s%s%s%s%s",
+    write_log(WRITE_LOG_SYS, "received%s%s%s%s%s%s%s%s%s%s%s%ld%s%s%s%s%s",
 	      "\n|\t     from: ", sender,
 		host_string?
 	      "\n|\t     host: ": "", host_string? host_string: "",
