@@ -1,5 +1,5 @@
 /*
-#ident	"@(#)smail/src:RELEASE-3_2_0_101:resolve.c,v 1.11 1997/12/12 22:16:03 woods Exp"
+#ident	"@(#)smail/src:RELEASE-3_2_0_102:resolve.c,v 1.13 1998/08/02 17:41:35 woods Exp"
  */
 
 /*
@@ -166,14 +166,12 @@ resolve_addr_list(in, out, defer, fail, hash_addrs)
 	    default:			/* anything else is a remote-form address */
 		/* determine if the target host is actually a local host */
 		if (islocalhost(cur->target)) {
-		    DEBUG1(DBG_RESOLVE_HI, "target %s was actually a local host.\n", cur->target);
+		    DEBUG1(DBG_RESOLVE_HI, "target %s was actually a local host, will reparse remainder.\n", cur->target);
 		    /* remember the local name */
 		    cur->local_name = COPY_STRING(cur->target);/* XXX will leak? */
 		    /* it is a local host, but save the name for virtual host processing */
 		    cur->work_addr = COPY_STRING(cur->remainder);/* XXX will leak? */
-		    /* pass the current address to the local directors */
-		    cur->succ = local;
-		    local = cur;
+		    next = cur;		/* erni: must parse again, remainder could be remote */
 		    continue;
 		}
 		cur->flags &= ~(ADDR_FORM_MASK);
@@ -212,9 +210,12 @@ resolve_addr_list(in, out, defer, fail, hash_addrs)
 	 */
 	for (cur = *out, prev = NULL; cur; cur = next) {
 	    next = cur->succ;
-	    hashval = xprintf("%s:%s", cur->next_addr, cur->transport->name);
+	    hashval = xprintf("%s at %s via %s",
+			      cur->next_addr,
+			      cur->next_host ? cur->next_host : "(localhost)",
+			      cur->transport->name);
 	    if (add_to_hash(hashval, (char *) NULL, 0, hit_out_table) == ALREADY_HASHED) {
-		DEBUG2(DBG_RESOLVE_LO, "%s via %s: has already been seen -- skipping.\n", cur->next_addr, cur->transport->name);
+		DEBUG1(DBG_RESOLVE_LO, "%s: has already been seen -- skipping.\n", hashval);
 		prev->succ = next;
 		cur->succ = NULL;
 		/* XXX should probably garbage collect the duplicate */
