@@ -1,5 +1,5 @@
 /*
-#ident	"@(#)smail/src:RELEASE-3_2_0_101:retry.c,v 1.30 1997/12/16 22:11:58 woods Exp"
+#ident	"@(#)smail/src:RELEASE-3_2_0_102:retry.c,v 1.31 1998/04/11 23:30:46 woods Exp"
  */
 
 /*
@@ -853,7 +853,7 @@ tryfile_mkdir(sp)
 	DEBUG1(DBG_RETRY_LO, "make directory %s\n", sp->p);
 	(void) mkdir(sp->p, auto_mkdir_mode);
 	if (stat(sp->p, &statbuf) == -1) {
-	    write_log(LOG_SYS, "can't create directory %s", sp->p);
+	    write_log(WRITE_LOG_SYS, "can't create directory %s", sp->p);
 	    ret = FAIL;
 	}
     }
