@@ -1,5 +1,5 @@
 /*
-#ident	"@(#)smail/src:RELEASE-3_2_0_101:route.c,v 1.28 1997/12/11 20:48:00 woods Exp"
+#ident	"@(#)smail/src:RELEASE-3_2_0_102:route.c,v 1.29 1998/04/11 23:30:49 woods Exp"
  */
 
 /*
@@ -862,7 +862,7 @@ next_addr_basic(addr, inet)
 	 * and send as UUCP-style address.
 	 */
 
-	write_log(LOG_PANIC, "internal error: next_addr_local: unknown form: in_addr:%s target:%s remainder:%s",
+	write_log(WRITE_LOG_PANIC, "internal error: next_addr_local: unknown form: in_addr:%s target:%s remainder:%s",
 		  addr->in_addr, target, remainder);
 
 	if (route)
