@@ -1,5 +1,5 @@
 /*
-#ident	"@(#)smail/src/routers:RELEASE-3_2_0_101:rewrite.c,v 1.10 1997/12/11 23:09:38 woods Exp"
+#ident	"@(#)smail/src/routers:RELEASE-3_2_0_102:rewrite.c,v 1.12 1998/07/05 17:53:01 woods Exp"
  */
 /*
  * rewrite.c
@@ -397,6 +397,8 @@ rewrite_lookup(rp, addr, fl, rt_info, error_p)
     int form;		/* form of remainder */
     char *error;	/* error from some lower-level functions */
     char *new_address;	/* rewritten address */
+    char *new_target;	/* target of rewritten address */
+    char *new_remainder; /* remainder of rewritten address */
 
     /* is the target in the database? */
     result = find_domain(rp, addr, &raw_data, &match, error_p);
@@ -430,8 +432,10 @@ rewrite_lookup(rp, addr, fl, rt_info, error_p)
 	return DB_AGAIN;
     }
     flag = p;
-    while (*p && !isspace(*p)) p++;
-    while (*p && isspace(*p)) p++;
+    while (*p && !isspace(*p))
+	p++;				/* skip the flags */
+    while (*p && isspace(*p))
+	p++;				/* and move to the next token */
     format = p; /* might be empty string.  check later if we care */
 
     /* does the database say we should rewrite this address? */
@@ -445,10 +449,17 @@ rewrite_lookup(rp, addr, fl, rt_info, error_p)
 		}
     default:	*error_p = bad_entry(rp, raw_data);
 		return DB_AGAIN;
-    };
+    }
+
+    /*
+     * raw_data points to a static area which is overwritten by calls
+     * to other lookup routines.  preserve the portion format points to
+     * for error messages.
+     */
+    format = COPY_STRING(format);
 
     /* is the remainder a simple user name? */
-    form = parse_address(addr->remainder, (char **)0, &error, (int *)0);
+    form = parse_address(addr->remainder, (char **) NULL, &error, (int *) NULL);
     switch (form) {
     case LOCAL:
 	    /* rewrite mailbox@target according to specified format */
@@ -463,18 +474,16 @@ rewrite_lookup(rp, addr, fl, rt_info, error_p)
 		temp_addr.next_addr = addr->remainder;	/* for ${user} */
 		temp_addr.next_host = addr->target;	/* for ${host} */
 
-		new_address = expand_string(format,
-					    &temp_addr, (char *)NULL, addr->remainder);
+		new_address = expand_string(COPY_STRING(format), &temp_addr, (char *) NULL, addr->remainder);
 	    }
-	    if (new_address == NULL) {
-		*error_p = expand_error(rp, format);
+	    if (!new_address) {
+		*error_p = expand_error(rp, format, (char *) NULL);
 		return DB_AGAIN;
 	    }
 
-	    /* preparse to strip comments etc. */
-	    p = preparse_address(new_address, &error);
-	    if (p == NULL) {
-		*error_p = expand_error(rp, format);
+	    /* preparse to canonicalize, strip comments, etc. */
+	    if (!(p = preparse_address(new_address, &error))) {
+		*error_p = expand_error(rp, format, xprintf("%s \"%s\"", error, new_address));
 		return DB_AGAIN;
 	    }
 	    new_address = p;
@@ -486,11 +495,22 @@ rewrite_lookup(rp, addr, fl, rt_info, error_p)
 	    break;
     }
 
-    /* is rewritten address the same as before rewriting? */
-    if (EQIC(new_address, addr->in_addr)) {
-	DEBUG2(DBG_DRIVER_HI, "rewrite_lookup: not rewriting %s --> %s\n",
-	       addr->in_addr, new_address);
-	return DB_NOMATCH;
+    /* is the rewritten address the same as it was before rewriting? */
+    /* XXX leaking memory below.... */
+    /* XXX should we compare the resulting 'form' too? */
+    if (parse_address(COPY_STRING(new_address), &new_target, &new_remainder, (int *) NULL) == FAIL) {
+	DEBUG3(DBG_DRIVER_LO, "rewrite_lookup: rewritten address %s --> %s not parsable: %s\n",
+	       addr->in_addr, new_address, new_remainder);
+	/*
+	 * don't return DB_AGAIN; the fault is probably in the
+	 * original address and will be handled elsewhere.
+	 */
+    } else {
+	if (EQIC(new_target, addr->target) && EQIC(new_remainder, addr->remainder)) {
+	    DEBUG3(DBG_DRIVER_HI, "rewrite_lookup: not rewriting %s --> %s at %s\n",
+		   addr->in_addr, new_target, new_remainder);
+	    return DB_NOMATCH;
+	}
     }
 
     /*
@@ -865,9 +885,10 @@ lookup_error(rp, target, lookup_error_text)
 }
 
 static struct error *
-expand_error(rp, format)
+expand_error(rp, format, infop)
     struct router *rp;
     char *format;
+    char *infop;
 {
     char *error_text;
 
@@ -885,8 +906,13 @@ expand_error(rp, format)
      *      The postmaster should fix the entry in the
      *	    rewrite database.
      */
-    error_text = xprintf("router %s: expansion of \"%s\" failed",
-			 rp->name, format);
+    if (!infop) {
+	error_text = xprintf("router %s: expansion of \"%s\" failed",
+			     rp->name, format);
+    } else {
+	error_text = xprintf("router %s: expansion of \"%s\" failed: %s",
+			     rp->name, format, infop);
+    }
     DEBUG1(DBG_DRIVER_LO, "%s\n", error_text);
     return note_error(ERR_CONFERR|ERR_1204, error_text);
 }
