@@ -1,5 +1,5 @@
 /*
-#ident	"@(#)smail/src/routers:RELEASE-3_2_0_101:uuname.c,v 1.6 1996/02/26 18:38:14 woods Exp"
+#ident	"@(#)smail/src/routers:RELEASE-3_2_0_102:uuname.c,v 1.7 1998/01/11 06:58:34 woods Exp"
  */
 
 /*
@@ -401,7 +401,11 @@ read_command(priv, error)
     struct str str;			/* string region */
     register int c;			/* character from uuname command */
     static char *argv[] = {		/* args for shell */
+#ifdef SHELL_EXEC_PATH
+	SHELL_EXEC_PATH,
+#else
 	"/bin/sh",
+#endif
 	"-c",
 	NULL,
 	NULL,
