@@ -1,5 +1,5 @@
 /*
-#ident	"@(#)smail/src:RELEASE-3_2_0_101:smtprecv.c,v 1.70 1997/12/08 05:13:40 woods Exp"
+#ident	"@(#)smail/src:RELEASE-3_2_0_102:smtprecv.c,v 1.72 1998/06/08 01:02:07 woods Exp"
  */
 
 /*
@@ -245,7 +245,7 @@ receive_smtp(in, out)
 	    static done_it = 0;
 
 	    if (!done_it) {
-		write_log(LOG_PANIC, "expand_string(): failed for smtp_banner='%s'.",
+		write_log(WRITE_LOG_PANIC, "expand_string(): failed for smtp_banner='%s'.",
 			  smtp_banner);
 		done_it++;
 	    }
@@ -369,7 +369,7 @@ receive_smtp(in, out)
 	    if (out && smtp_session_denied) {
 		fprintf(out, "550 You are not permitted to send mail\r\n");
 		fflush(out);
-		write_log(LOG_SYS, "remote %s: refusing SMTP connection from %s%s%s%s%s.",
+		write_log(WRITE_LOG_SYS, "remote %s: refusing SMTP connection from %s%s%s%s%s.",
 			  ehlo_p ? "EHLO" : "HELO",
 			  ident_sender ? ident_sender : "", ident_sender ? "@" : "",
 			  sender_host_addr ? "[" : "",
@@ -420,7 +420,7 @@ receive_smtp(in, out)
 		    fflush(out);
 		}
 		if (!sender_host || error) { /* log even "hidden" errors as warnings */
-		    write_log(LOG_SYS, "remote %s: %s operand: '%s': from %s%s%s%s%s%s%s%s%s%s%s.",
+		    write_log(WRITE_LOG_SYS, "remote %s: %s operand: '%s': from %s%s%s%s%s%s%s%s%s%s%s.",
 			      ehlo_p ? "EHLO" : "HELO",
 			      sender_host ? "questionable" : "invalid",
 			      orig_data,
@@ -500,7 +500,7 @@ receive_smtp(in, out)
 			sender_host_addr ? sender_host_addr : "",
 			sender_host_addr ? "]" : "");
 		fflush(out);
-		write_log(LOG_SYS, "remote MAIL FROM: '%s' refusing SMTP connection from %s%s%s%s%s%s%s%s%s%s",
+		write_log(WRITE_LOG_SYS, "remote MAIL FROM: '%s' refusing SMTP connection from %s%s%s%s%s%s%s%s%s%s",
 			  data, ident_sender ? ident_sender : "", ident_sender ? "@" : "",
 			  sender_host ? sender_host : "",
 			  sender_host_really ? "(" : "",
@@ -685,7 +685,7 @@ receive_smtp(in, out)
 			sender_host_addr ? sender_host_addr : "",
 			sender_host_addr ? "]" : "");
 		fflush(out);
-		write_log(LOG_SYS, "remote MAIL TO: '%s' refusing SMTP connection from %s%s%s%s%s%s%s%s%s%s",
+		write_log(WRITE_LOG_SYS, "remote MAIL TO: '%s' refusing SMTP connection from %s%s%s%s%s%s%s%s%s%s",
 			  data, ident_sender ? ident_sender : "", ident_sender ? "@" : "",
 			  sender_host ? sender_host : "",
 			  sender_host_really ? "(" : "",
@@ -868,7 +868,7 @@ receive_smtp(in, out)
 			sender_host_addr ? sender_host_addr : "",
 			sender_host_addr ? "]" : "");
 		fflush(out);
-		write_log(LOG_SYS, "remote EXPN: '%s' refusing SMTP connection from %s%s%s%s%s%s%s%s%s%s",
+		write_log(WRITE_LOG_SYS, "remote EXPN: '%s' refusing SMTP connection from %s%s%s%s%s%s%s%s%s%s",
 			  data, ident_sender ? ident_sender : "", ident_sender ? "@" : "",
 			  sender_host ? sender_host : "",
 			  sender_host_really ? "(" : "",
@@ -933,7 +933,7 @@ receive_smtp(in, out)
 			sender_host_addr ? sender_host_addr : "",
 			sender_host_addr ? "]" : "");
 		fflush(out);
-		write_log(LOG_SYS, "remote DEBUG: '%s' refusing SMTP connection from %s%s%s%s%s%s%s%s%s%s",
+		write_log(WRITE_LOG_SYS, "remote DEBUG: '%s' refusing SMTP connection from %s%s%s%s%s%s%s%s%s%s",
 			  data, ident_sender ? ident_sender : "", ident_sender ? "@" : "",
 			  sender_host ? sender_host : "",
 			  sender_host_really ? "(" : "",
@@ -1142,7 +1142,7 @@ expand_addr(in_addr, out)
     char *error;			/* hold error message */
 
 # ifndef NO_LOG_SMTP_EXPN
-    write_log(LOG_SYS, "remote EXPN: '%s' by %s%s%s%s%s%s%s%s%s.", in_addr,
+    write_log(WRITE_LOG_SYS, "remote EXPN: '%s' by %s%s%s%s%s%s%s%s%s.", in_addr,
 	      ident_sender ? ident_sender : "", ident_sender ? "@" : "",
 	      sender_host ? sender_host : "",
 	      sender_host_really ? "(" : "",
@@ -1221,7 +1221,7 @@ verify_sender(pp_sender, raw_sender, out)
     if (*vaddr->work_addr && !EQ(vaddr->work_addr, "+") && form == LOCAL) {
 	fprintf(out, "501 '%s' sender address cannot be a local or unqualified address (i.e. it must have a domain portion).\r\n", vaddr->work_addr);
 	fflush(out);
-	write_log(LOG_SYS, "remote MAIL FROM: '%s' is a local address; by %s%s%s%s%s%s.",
+	write_log(WRITE_LOG_SYS, "remote MAIL FROM: '%s' is a local address; by %s%s%s%s%s%s.",
 		  vaddr->in_addr,
 		  ident_sender ? ident_sender : "", ident_sender ? "@" : "",
 		  sender_host,
@@ -1240,7 +1240,7 @@ verify_sender(pp_sender, raw_sender, out)
 		(form == BERKENET) ? "BERKENET" :
 			(form == DECNET) ? "DECNET" : "<bad-form!>");
 	fflush(out);
-	write_log(LOG_SYS, "remote MAIL FROM: '%s' is a %s address; by %s%s%s%s%s%s.",
+	write_log(WRITE_LOG_SYS, "remote MAIL FROM: '%s' is a %s address; by %s%s%s%s%s%s.",
 		  vaddr->in_addr,
 		  (form == BERKENET) ? "BERKENET" :
 			(form == DECNET) ? "DECNET" : "<bad-form!>",
@@ -1259,7 +1259,7 @@ verify_sender(pp_sender, raw_sender, out)
 	 * XXX Do we really want to allow RFC_ROUTE/RFC_ENDROUTE addresses?
 	 * XXX What about other forms (eg. UUCP_ROUTE, PCT_MAILBOX)?
 	 */
-	write_log(LOG_SYS, "remote MAIL FROM: '%s' (target %s) is a %s address; by %s%s%s%s%s%s.",
+	write_log(WRITE_LOG_SYS, "remote MAIL FROM: '%s' (target %s) is a %s address; by %s%s%s%s%s%s.",
 		  vaddr->in_addr, vaddr->target,
 		  (form == RFC_ROUTE) ? "RFC_ROUTE" :
 			(form == RFC_ENDROUTE) ? "RFC_ENDROUTE" :
@@ -1324,7 +1324,7 @@ verify_sender(pp_sender, raw_sender, out)
 		    vaddr->in_addr, vaddr->target,
 		    smtp_sender_verify_mx_only ? " (there is no MX record for it)" : "");
 	    fflush(out);
-	    write_log(LOG_SYS, "remote MAIL FROM: '%s' target '%s' is not a valid domain%s; by %s%s%s%s%s%s.",
+	    write_log(WRITE_LOG_SYS, "remote MAIL FROM: '%s' target '%s' is not a valid domain%s; by %s%s%s%s%s%s.",
 		      vaddr->in_addr, vaddr->target,
 		      smtp_sender_verify_mx_only ? " (no MX record)" : "",
 		      ident_sender ? ident_sender : "", ident_sender ? "@" : "",
@@ -1343,7 +1343,7 @@ verify_sender(pp_sender, raw_sender, out)
 		    vaddr->in_addr, vaddr->target,
 		    (binderr->message && *binderr->message) ? binderr->message : "Unknown error");
 	    fflush(out);
-	    write_log(LOG_SYS, "remote MAIL FROM: '%s' target '%s': DNS failed: %s; by %s%s%s%s%s%s.",
+	    write_log(WRITE_LOG_SYS, "remote MAIL FROM: '%s' target '%s': DNS failed: %s; by %s%s%s%s%s%s.",
 		      vaddr->in_addr, vaddr->target,
 		      (binderr->message && *binderr->message) ? binderr->message : "Unknown error",
 		      ident_sender ? ident_sender : "", ident_sender ? "@" : "",
@@ -1426,7 +1426,7 @@ verify_addr(in_addr, out, rcpt_p)
 		defer->error->info & ERR_MASK, defer->error->message);
 	if (rcpt_p) {
 	    /* XXX this may be very noisy.... */
-	    write_log(LOG_SYS, "remote %s%s%s%s%s%s: '%s' <%s@%s> temporary failure returned to '%s' while verifying recipient: (ERR_%03ld) %s",
+	    write_log(WRITE_LOG_SYS, "remote %s%s%s%s%s%s: '%s' <%s@%s> temporary failure returned to '%s' while verifying recipient: (ERR_%03ld) %s",
 		      ident_sender ? ident_sender : "",
 		      ident_sender ? "@" : "",
 		      sender_host,
@@ -1467,7 +1467,7 @@ verify_addr(in_addr, out, rcpt_p)
 		fail->work_addr, (fail->target) ? fail->target : "(nodomain)",
 		fail->error->info & ERR_MASK, fail->error->message);
 	if (rcpt_p) {
-	    write_log(LOG_SYS, "remote %s%s%s%s%s%s: '%s' <%s@%s> recipient for sender '%s' not matched: (ERR_%03ld) %s",
+	    write_log(WRITE_LOG_SYS, "remote %s%s%s%s%s%s: '%s' <%s@%s> recipient for sender '%s' not matched: (ERR_%03ld) %s",
 		      ident_sender ? ident_sender : "",
 		      ident_sender ? "@" : "",
 		      sender_host,
@@ -1489,7 +1489,7 @@ verify_addr(in_addr, out, rcpt_p)
 	    addr->work_addr, (addr->target) ? addr->target : "(nodomain)");
     if (rcpt_p) {
 	/* XXX do we really need to log these? */
-	write_log(LOG_SYS, "remote %s%s%s%s%s%s: '%s' <%s@%s> recipient for sender '%s' not matched by anything!",
+	write_log(WRITE_LOG_SYS, "remote %s%s%s%s%s%s: '%s' <%s@%s> recipient for sender '%s' not matched by anything!",
 		  ident_sender ? ident_sender : "", ident_sender ? "@" : "",
 		  sender_host,
 		  sender_host_addr ? "[" : "",
@@ -1521,15 +1521,16 @@ verify_host(hostnm, saddrp, shp, errorp)
     struct hostent *hp;
     char *p;
     int found;
+    int has_alphas;
     int i;
-    int host_not_broken = TRUE;
+    int allowed_to_be_broken = FALSE;
 
 # ifndef OBSOLETE_RESOLVER
     extern int h_errno;			/* import h_errno; many systems don't define it in <netdb.h> */
 # endif
 
     if (smtp_hello_broken_allow) {
-	host_not_broken = !match_ip(inet_ntoa(saddrp->sin_addr), smtp_hello_broken_allow);
+	    allowed_to_be_broken = match_ip(inet_ntoa(saddrp->sin_addr), smtp_hello_broken_allow);
     }
     if (*hostnm == '[') {
 # if defined(INET_ADDR_USE_STRUCT)
@@ -1560,7 +1561,7 @@ verify_host(hostnm, saddrp, shp, errorp)
 	if (inet != saddrp->sin_addr.s_addr) {
 	    DEBUG3(DBG_REMOTE_LO, "verify_host(%s): [0x%lx] != [0x%lx].\n", hostnm, inet, saddrp->sin_addr.s_addr);
 	    *errorp = "Host address does not match remote address";
-	    if (smtp_hello_verify && host_not_broken) {
+	    if (smtp_hello_verify && !allowed_to_be_broken) {
 		return NULL;		/* broken DNS or mailer config; or forger */
 	    }
 	}
@@ -1572,7 +1573,7 @@ verify_host(hostnm, saddrp, shp, errorp)
 	if (shp && sender_host_really) { /* both from gethostbyaddr() in caller */
 	    if (!(hp = gethostbyname(sender_host_really))) {
 		DEBUG2(DBG_REMOTE_LO, "verify_host(%s) gethostbyname() for verify_literal failed: %s.\n", sender_host_really, hstrerror(h_errno));
-		if (smtp_hello_verify_literal && host_not_broken) {
+		if (smtp_hello_verify_literal && !allowed_to_be_broken) {
 		    return NULL;	/* broken DNS or mailer config; or forger */
 		}
 	    } else {
@@ -1588,14 +1589,14 @@ verify_host(hostnm, saddrp, shp, errorp)
 		    DEBUG3(DBG_REMOTE_LO, "verify_host(%s) gethostbyname() doesn't find matching A [%s] for PTR %s.\n",
 			   hostnm, inet_ntoa(saddrp->sin_addr), sender_host_really);
 		    *errorp = "Host domain literal A name does not match PTR";
-		    if (smtp_hello_verify_literal && host_not_broken) {
+		    if (smtp_hello_verify_literal && !allowed_to_be_broken) {
 			return NULL;	/* broken DNS or mailer config; or forger */
 		    }
 		}
 	    }
 	} else {
 	    *errorp = "Remote address PTR lookup failed";
-	    if (smtp_hello_verify_literal && host_not_broken) {
+	    if (smtp_hello_verify_literal && !allowed_to_be_broken) {
 		return NULL;		/* broken DNS or mailer config; or forger */
 	    }
 	}
@@ -1612,26 +1613,43 @@ verify_host(hostnm, saddrp, shp, errorp)
     if (*hostnm == '.') {
 	*errorp = "hostname must not start with '.'";
 	DEBUG1(DBG_REMOTE_LO, "hostname must not start with '.': %s", hostnm);
-	if (host_not_broken) {
+	if (!allowed_to_be_broken) {
 	    return NULL;
 	}
     }
     found = 0;
+    has_alphas = 0;
     for (p = hostnm; *p; p++) {
+	if (isalpha(*p) || *p == '-')
+	    has_alphas = 1;
 	if (*p == '.') {
 	    found = 1;
 	} else if (!(isalnum(*p) || *p == '-')) {
             *errorp = "illegal character in hostname";
             DEBUG2(DBG_REMOTE_LO, "illegal char in hostname: %s, %c.\n", hostnm, *p);
-	    if (host_not_broken) {
+	    if (!allowed_to_be_broken) {
 		return NULL;
 	    }
         }
     }
     if (!found) {
 	*errorp = "hostname must contain a '.'";
-	DEBUG1(DBG_REMOTE_LO, "hostname must contain a '.': %s", hostnm);
-	if (host_not_broken) {
+	DEBUG1(DBG_REMOTE_LO, "hostname must contain a '.': %s.\n", hostnm);
+	if (!allowed_to_be_broken) {
+	    return NULL;
+	}
+    }
+    if (!has_alphas) {			/* gethostbyname() likes IP #s so don't go there! */
+	if (!inet_aton(hostnm, (struct in_addr *) NULL)) { /* XXX hope all allow NULL! */
+	    *errorp = "not a valid IP literal address, and not surrounted by `[]'";
+	    DEBUG1(DBG_REMOTE_LO, "not a valid literal IP, no []'s: %s.\n", hostnm);
+	    if (!allowed_to_be_broken) {
+		return NULL;
+	    }
+	}
+	*errorp = "IP literal addresses must be surrounded by `[]'";
+	DEBUG1(DBG_REMOTE_LO, "literal IP without []'s: %s.\n", hostnm);
+	if (!allowed_to_be_broken) {
 	    return NULL;
 	}
     }
@@ -1655,21 +1673,22 @@ verify_host(hostnm, saddrp, shp, errorp)
 	    if (!found) {
 		DEBUG2(DBG_REMOTE_LO, "verify_host(%s): gethostbyaddr(%s) PTR does not have matching name.\n", hostnm, inet_ntoa(saddrp->sin_addr));
 		*errorp = "Remote address PTR does not have matching name";
-		if (smtp_hello_verify_ptr && host_not_broken) {
+		if (smtp_hello_verify_ptr && !allowed_to_be_broken) {
 		    return NULL;	/* broken DNS or mailer config; or forger */
 		}
 	    }
 	}
     } else {
 	*errorp = "Remote address PTR lookup failed";
-	if (smtp_hello_verify_ptr && host_not_broken) {
+	if (smtp_hello_verify_ptr && !allowed_to_be_broken) {
 	    return NULL;		/* broken DNS or mailer config; or forger */
 	}
     }
     if (!(hp = gethostbyname(hostnm))) { /* NOTE: must have checked shp by now.... */
+	*errorp = hstrerror(h_errno);
 	DEBUG2(DBG_REMOTE_LO, "verify_host(%s) gethostbyname() failed: %s.\n", hostnm, hstrerror(h_errno));
 	/* XXX it might be nice to return a temporary error here, but that would mean a re-design */
-	if (smtp_hello_verify && host_not_broken) {
+	if (smtp_hello_verify && !allowed_to_be_broken) {
 	    return NULL;
 	}
     } else {
@@ -1684,7 +1703,7 @@ verify_host(hostnm, saddrp, shp, errorp)
 	if (!found) {
 	    DEBUG2(DBG_REMOTE_LO, "verify_host(%s) gethostbyname() doesn't find %s.\n", hostnm, inet_ntoa(saddrp->sin_addr));
 	    *errorp = "Host name does not match remote address";
-	    if (smtp_hello_verify && host_not_broken) {
+	    if (smtp_hello_verify && !allowed_to_be_broken) {
 		return NULL;		/* broken DNS or mailer config; or forger */
 	    }
 	}
@@ -1763,7 +1782,7 @@ smtp_receive_timeout_sig(sig)
 {
     fprintf(out_file, "421 %s SMTP command timeout, closing channel\r\n",
 	    primary_name);
-    write_log(LOG_SYS, "SMTP connection timeout%s%s%s%s%s.",
+    write_log(WRITE_LOG_SYS, "SMTP connection timeout%s%s%s%s%s.",
 	      sender_host? " while talking with ": "",
 	      sender_host? sender_host: "",
 	      sender_host_addr? " [": "",
