@@ -1,5 +1,5 @@
 /*
-#ident	"@(#)smail/src:RELEASE-3_2_0_101:spool.c,v 1.25 1997/12/16 22:12:01 woods Exp"
+#ident	"@(#)smail/src:RELEASE-3_2_0_102:spool.c,v 1.26 1998/04/11 23:30:56 woods Exp"
  */
 
 /*
@@ -694,7 +694,7 @@ check_empty_lock(stp)
 	 * in the past.  Since this version of smail has not been
 	 * written yet, punt.
 	 */
-	write_log(LOG_SYS|LOG_CONS, "machine is in a time warp, check date");
+	write_log(WRITE_LOG_SYS|WRITE_LOG_CONS, "machine is in a time warp, check date");
 	return SUCCEED;
     }
 
@@ -704,7 +704,7 @@ check_empty_lock(stp)
 	 * otherwise assume it is a valid lock.
 	 */
 	(void) chmod(lock_fn, stp->st_mode);
-	write_log(LOG_SYS, "time warp on zero length lock file: %s", lock_fn);
+	write_log(WRITE_LOG_SYS, "time warp on zero length lock file: %s", lock_fn);
 	return SUCCEED;
     }
     if (stp->st_ctime < now - 2*3600/*two hours in seconds*/) {
@@ -1183,13 +1183,13 @@ defer_message()
 	success = link(save_input_spool_fn, error_fn);
     }
     if (success < 0) {
-	write_log(LOG_PANIC|LOG_SYS,
+	write_log(WRITE_LOG_PANIC|WRITE_LOG_SYS,
 		  "defer_message: error linking %s/%s to %s/%s: %s",
 		  spool_dir, save_input_spool_fn, spool_dir, error_fn,
 		  strerror(errno));
     } else {
 	if (errfile) {
-	    write_log(LOG_TTY|LOG_SYS, "mail moved to %s/%s",
+	    write_log(WRITE_LOG_TTY|WRITE_LOG_SYS, "mail moved to %s/%s",
 		      spool_dir, error_fn);
 	}
 	input_spool_fn = save_input_spool_fn;
@@ -1420,7 +1420,7 @@ log_spool_errors()
     DEBUG(DBG_SPOOL_HI, "log_spool_errors called, saving any errors from spool\n");
     while (log_msgs) {
 	next = log_msgs->succ;
-	write_log(LOG_PANIC, "%s", log_msgs->msg);
+	write_log(WRITE_LOG_PANIC, "%s", log_msgs->msg);
 	xfree((char *)log_msgs);
 	log_msgs = next;
     }
