@@ -1,5 +1,5 @@
 /*
-#ident	"@(#)smail/src:RELEASE-3_2_0_101:sysdep.c,v 1.67 1997/12/16 22:22:20 woods Exp
+#ident	"@(#)smail/src:RELEASE-3_2_0_102:sysdep.c,v 1.71 1998/04/12 02:02:06 woods Exp
  */
 
 /*
@@ -68,6 +68,16 @@
 # endif
 #endif	/* not POSIX_OS */
 
+#ifndef STDERR_FILENO
+# define STDIN_FILENO	0	/* standard input file descriptor */
+#endif
+#ifndef STDOUT_FILENO
+# define STDOUT_FILENO	1	/* standard output file descriptor */
+#endif
+#ifndef STDERR_FILENO
+# define STDERR_FILENO	2	/* standard error file descriptor */
+#endif
+
 #ifdef	HAVE_UNAME
 # include <sys/utsname.h>
 #endif
@@ -517,7 +527,7 @@ fopen_as_user(fn, type, uid, gid, mode)
 	   fn, type, uid, gid, mode);
     /* reject non-root-based paths out of hand, though we shouldn't get any */
     if (!fn || fn[0] != '/') {
-	write_log(LOG_SYS|LOG_PANIC,
+	write_log(WRITE_LOG_SYS|WRITE_LOG_PANIC,
 		  "fopen_as_user: given non-root anchored path: %s",
 		  fn);
 	errno = EACCES;
@@ -687,7 +697,7 @@ fopen_as_user(fn, type, uid, gid, mode)
 	    close(cfd);
 	    if ((stb_root.st_dev != stb_user.st_dev) ||
 		(stb_root.st_ino != stb_user.st_ino)) {
-		write_log(LOG_SYS|LOG_PANIC,	/* XXX child writing to log here!!! */
+		write_log(WRITE_LOG_SYS|WRITE_LOG_PANIC,	/* XXX child writing to log here!!! */
 			  "fopen_as_user: parent/child file mismatch!: %s.\n", fn);
 		exit(EACCES + 1);		/* got a better idea? */
 	    }
@@ -1318,6 +1328,7 @@ compute_domain ( hostname )
  *
  *		CHILD_DUPERR	- duplicate stdout to stderr in the
  *				  child process.
+ *		CHILD_CLSERR	- close stderr in the child process.
  *		CHILD_DEVNULL	- open "/dev/null" and associate it
  *				  with stdin and/or stdout in the
  *				  child process, if no in and/or out
@@ -1369,9 +1380,13 @@ open_child(argv, envp, in, out, errfd, flags, uid, gid)
     static char **minp = NULL;
 
     if (in && pipe(stdin_fd) < 0) {
+	write_log(WRITE_LOG_TTY | WRITE_LOG_PANIC,
+		  "open_child(%s): pipe(stdin_fd) failed: %s", argv[0], strerror(errno));
 	return EOF;
     }
     if (out && pipe(stdout_fd) < 0) {
+	write_log(WRITE_LOG_TTY | WRITE_LOG_PANIC,
+		  "open_child(%s): pipe(stdout_fd) failed: %s", argv[0], strerror(errno));
 	/* free resources */
 	if (in) {
 	    (void) close(stdin_fd[0]);
@@ -1383,7 +1398,7 @@ open_child(argv, envp, in, out, errfd, flags, uid, gid)
     /* keep trying to create a fork until we succeed or retries == 0 */
     while (
 #if	(defined(UNIX_BSD) || defined(HAVE_VFORK)) && !defined(DONT_USE_VFORK)
-	   (pid = (argv? vfork(): fork())) < 0 &&
+	   (pid = (argv ? vfork() : fork())) < 0 &&
 #else	/* not UNIX_BSD && not HAVE_VFORK */
 	   (pid = fork()) < 0 &&
 #endif	/* UNIX_BSD || HAVE_VFORK */
@@ -1393,6 +1408,8 @@ open_child(argv, envp, in, out, errfd, flags, uid, gid)
 	(void) sleep(FORK_INTERVAL);	/* sleep between retries */
     }
     if (pid < 0) {
+	write_log(WRITE_LOG_TTY | WRITE_LOG_PANIC,
+		  "open_child(%s): fork() failed: %s", argv[0], strerror(errno));
 	/* free resources */
 	if (in) {
 	    (void) close(stdin_fd[0]);
@@ -1417,11 +1434,11 @@ open_child(argv, envp, in, out, errfd, flags, uid, gid)
 	}
 
 	/* if errfd == 0, watch out for the code below */
-	if (errfd == 0 || errfd == 1) {
+	if (errfd == STDIN_FILENO || errfd == STDOUT_FILENO) {
 	    int new_errfd;
 
 	    /* search for a descriptor we don't care about */
-	    for (new_errfd = 3; new_errfd < 10; new_errfd++) {
+	    for (new_errfd = (STDERR_FILENO + 1); new_errfd < 10; new_errfd++) {
 		if ((in && new_errfd == stdin_fd[0]) ||
 		    (out && new_errfd == stdout_fd[1]))
 		{
@@ -1429,7 +1446,12 @@ open_child(argv, envp, in, out, errfd, flags, uid, gid)
 		}
 		break;
 	    }
-	    (void) dup2(errfd, new_errfd);
+	    if (dup2(errfd, new_errfd) == -1) {
+		/* XXX this debug may not even print!!! */
+		write_log(WRITE_LOG_TTY | WRITE_LOG_PANIC,
+			  "open_child(%s): dup2(errfd, new_errfd) failed: %s", argv[0], strerror(errno));
+		_exit(EX_OSERR);
+	    }
 	    (void) close(errfd);
 	    errfd = new_errfd;
 	}
@@ -1439,8 +1461,13 @@ open_child(argv, envp, in, out, errfd, flags, uid, gid)
 	     */
 	    if (in) {
 		/* pipe from parent process */
-		if (stdin_fd[0] != 0) {
-		    (void) dup2(stdin_fd[0], 0);
+		if (stdin_fd[0] != STDIN_FILENO) {
+		    if (dup2(stdin_fd[0], STDIN_FILENO) == -1) {
+			/* XXX this debug may not even print!!! */
+			write_log(WRITE_LOG_TTY | WRITE_LOG_PANIC,
+				  "open_child(%s): dup2(stdin_fd[0], 0) failed: %s", argv[0], strerror(errno));
+			_exit(EX_OSERR);
+		    }
 		    (void) close(stdin_fd[0]);
 		}
 	    } else if (flags & CHILD_DEVNULL) {
@@ -1450,9 +1477,11 @@ open_child(argv, envp, in, out, errfd, flags, uid, gid)
 		 *	 stdout_fd[1], which would not be nice.
 		 */
 		/* open /dev/null as the stdin */
-		(void) close(0);
-		if (open("/dev/null", O_RDONLY) < 0) {
+		(void) close(STDIN_FILENO);
+		if (open("/dev/null", O_RDONLY) < 0) { /* XXX assumes will re-open on just closed fd!!!! */
 		    /* uggh! failed to open /dev/null, quit without flush */
+		    write_log(WRITE_LOG_TTY | WRITE_LOG_PANIC,
+			      "open_child(%s): open(/dev/null, O_RDONLY) failed: %s", argv[0], strerror(errno));
 		    _exit(EX_OSFILE);
 		}
 	    }
@@ -1464,18 +1493,30 @@ open_child(argv, envp, in, out, errfd, flags, uid, gid)
 	     */
 	    if (out) {
 		/* pipe to parent process */
-		if (stdout_fd[1] != 1) {
-		    (void) dup2(stdout_fd[1], 1);
+		if (stdout_fd[1] != STDOUT_FILENO) {
+		    if (dup2(stdout_fd[1], STDOUT_FILENO) == -1) {
+			/* XXX this debug may not even print!!! */
+			write_log(WRITE_LOG_TTY | WRITE_LOG_PANIC,
+				  "open_child(%s): dup2(stdin_fd[1], 1) failed: %s", argv[0], strerror(errno));
+			_exit(EX_OSERR);
+		    }
 		    (void) close(stdout_fd[1]);
 		}
 	    } else if (errfd >= 0) {
 		/* use the given fd for stdout */
-		(void) dup2(errfd, 1);
+		if (dup2(errfd, STDOUT_FILENO) == -1) {
+		    /* XXX this debug may not even print!!! */
+		    write_log(WRITE_LOG_TTY | WRITE_LOG_PANIC,
+			      "open_child(%s): dup2(errfd, 1) failed: %s", argv[0], strerror(errno));
+		    _exit(EX_OSERR);
+		}
 	    } else if (flags & CHILD_DEVNULL) {
 		/* open /dev/null as stdout */
-		(void) close(1);
-		if (open("/dev/null", O_WRONLY) < 0) {
+		(void) close(STDOUT_FILENO);
+		if (open("/dev/null", O_WRONLY) < 0) { /* XXX assumes will re-open on just closed fd!!!! */
 		    /* uggh! failed to open /dev/null, quit without flush */
+		    write_log(WRITE_LOG_TTY | WRITE_LOG_PANIC,
+			      "open_child(%s): open(/dev/null, O_WRONLY) failed: %s", argv[0], strerror(errno));
 		    _exit(EX_OSFILE);
 		}
 	    }
@@ -1483,17 +1524,29 @@ open_child(argv, envp, in, out, errfd, flags, uid, gid)
 
 	if (errfd >= 0) {
 	    /* use this fd as the stderr */
-	    if (errfd != 2) {
-		(void) dup2(errfd, 2);
+	    if (errfd != STDERR_FILENO) {
+		if (dup2(errfd, STDERR_FILENO) == -1) {
+		    /* XXX this debug may not even print!!! */
+		    write_log(WRITE_LOG_TTY | WRITE_LOG_PANIC,
+			      "open_child(%s): dup2(errfd, 2) failed: %s", argv[0], strerror(errno));
+		    _exit(EX_OSERR);
+		}
 		(void) close(errfd);
 	    }
 	} else if (flags & CHILD_DUPERR) {
 	    /* duplicate stdout to get the stderr */
-	    (void) dup2(1, 2);
-	} else {
-	    (void) close(2);
-	    if (open("/dev/null", O_WRONLY) < 0) {
-		/* uggh! failed to open /dev/null, quit witout flush */
+	    if (dup2(STDOUT_FILENO, STDERR_FILENO) == -1) {
+		/* XXX this debug may not even print!!! */
+		write_log(WRITE_LOG_TTY | WRITE_LOG_PANIC,
+			  "open_child(%s): dup2(1, 2) failed: %s", argv[0], strerror(errno));
+		_exit(EX_OSERR);
+	    }
+	} else if (flags & CHILD_CLSERR) {
+	    (void) close(STDERR_FILENO);
+	    if (open("/dev/null", O_WRONLY) < 0) { /* XXX assumes will re-open on just closed fd!!!! */
+		/* uggh! failed to open /dev/null, quit without flush */
+		write_log(WRITE_LOG_TTY | WRITE_LOG_PANIC,
+			  "open_child(%s): open(/dev/null) failed: %s", argv[0], strerror(errno));
 		_exit(EX_OSFILE);
 	    }
 	}
@@ -1503,39 +1556,58 @@ open_child(argv, envp, in, out, errfd, flags, uid, gid)
 	    close_all();
 	}
 
-	/* change uid and gid, if we can, don't bother to check */
-	/* XXX This makes me very uncomfortable.  Why don't we check? */
-	(void) setgid(gid);
-	(void) setuid(uid);
+	/* change uid and gid */
+	if (setgid(gid) == -1) {
+	    write_log(WRITE_LOG_TTY | ((geteuid() == 0) ? WRITE_LOG_PANIC : 0),
+		      "open_child(%s): setgid(%d) failed (possible local configuration error): %s", argv[0], gid, strerror(errno));
+	    _exit(EX_NOPERM);
+	}
+	if (setuid(uid) == -1) {
+	    write_log(WRITE_LOG_TTY | ((geteuid() == 0) ? WRITE_LOG_PANIC : 0),
+		      "open_child(%s): setuid(%d) failed (possible local configuration error): %s", argv[0], uid, strerror(errno));
+	    _exit(EX_NOPERM);
+	}
 
 	if (argv) {
+	    int oerrno;
+
 	    /* execute the program */
 	    if (envp) {
 		(void) execve(argv[0], argv, envp);
+		oerrno = errno;
+		DEBUG2(DBG_DRIVER_LO, "open_child(): execve(%s, envp): %s.\n", argv[0], strerror(errno));
 	    } else if (flags & CHILD_MINENV) {
 		if (minp == NULL) {
 		    /* pass through the TZ environment variable */
-		    char *tz = getenv("TZ");
+		    char *tz;
 
 		    for (minp = min_env; *minp; minp++)
 			;
 #ifndef CHILD_ENVIRON
-#ifdef SHELL_EXEC_PATH
+# ifdef SHELL_EXEC_PATH
 		    *minp++ = xprintf("SHELL=%s", SHELL_EXEC_PATH);
-#else
+# else
 		    *minp++ = "SHELL=/bin/sh";
-#endif
+# endif
 		    *minp++ = xprintf("PATH=%s", SECURE_PATH);
 #endif	/* CHILD_ENVIRON */
-		    if (tz)
+		    if ((tz = getenv("TZ"))) {
 			*minp++ = xprintf("TZ=%s", tz);
+		    }
 		}
 		(void) execve(argv[0], argv, min_env);
+		oerrno = errno;
+		DEBUG2(DBG_DRIVER_LO, "open_child(): execve(%s, minenv): %s.\n", argv[0], strerror(errno));
 	    } else {
 		(void) execv(argv[0], argv);
+		oerrno = errno;
+		DEBUG2(DBG_DRIVER_LO, "open_child(): execv(%s): %s.\n", argv[0], strerror(errno));
 	    }
 
 	    /* Oh well, all this work and we can't even exec the file */
+	    write_log(WRITE_LOG_TTY | WRITE_LOG_PANIC,
+		      "open_child(): exec(%s) failed (possible local configuration error): %s",
+		      argv[0], strerror(oerrno));
 	    _exit(EX_OSFILE);
 	}
     } else {
@@ -1543,12 +1615,29 @@ open_child(argv, envp, in, out, errfd, flags, uid, gid)
 	if (in) {
 	    /* close the child stdin, return the write-channel */
 	    (void) close(stdin_fd[0]);
-	    *in = fdopen(stdin_fd[1], "w");
+	    if (!(*in = fdopen(stdin_fd[1], "w"))) {
+		write_log(WRITE_LOG_TTY | WRITE_LOG_PANIC,
+			  "open_child(%s): fdopen(stdin_fd[1], w) failed: %s", argv[0], strerror(errno));
+		/* free resources */
+		(void) close(stdin_fd[1]);
+		if (out) {
+		    (void) close(stdout_fd[0]);
+		    (void) close(stdout_fd[1]);
+		}
+		return EOF;
+	    }
 	}
 	if (out) {
 	    /* close the child stdout, return the read-channel */
 	    (void) close(stdout_fd[1]);
-	    *out = fdopen(stdout_fd[0], "r");
+	    if (!(*out = fdopen(stdout_fd[0], "r"))) {
+		write_log(WRITE_LOG_TTY | WRITE_LOG_PANIC,
+			  "open_child(%s): fdopen(stdout_fd[1], r) failed: %s", argv[0], strerror(errno));
+		/* free remaining resources */
+		(void) close(stdout_fd[0]);
+
+		return EOF;
+	    }
 	}
     }
 
