@@ -1,5 +1,5 @@
 /*
-#ident	"@(#)smail/src:RELEASE-3_2_0_101:transport.c,v 1.30 1997/12/16 22:12:05 woods Exp"
+#ident	"@(#)smail/src:RELEASE-3_2_0_102:transport.c,v 1.31 1998/04/11 23:31:04 woods Exp"
  */
 
 /*
@@ -376,7 +376,7 @@ call_transports(asn, defer, fail)
 
 		if (shadow_tp == NULL) {
 		    send_to_postmaster = TRUE;
-		    write_log(LOG_SYS|LOG_MLOG,
+		    write_log(WRITE_LOG_SYS|WRITE_LOG_MLOG,
 			      "transport %s: shadow transport %s not found",
 			      tp->name, tp->shadow);
 		} else {
@@ -414,7 +414,7 @@ call_transports(asn, defer, fail)
 
 		if (error_tp == NULL) {
 		    send_to_postmaster = TRUE;
-		    write_log(LOG_SYS|LOG_MLOG,
+		    write_log(WRITE_LOG_SYS|WRITE_LOG_MLOG,
 			      "transport %s: error transport %s not found",
 			      tp->name, tp->error_transport);
 		} else {
@@ -453,7 +453,7 @@ call_transports(asn, defer, fail)
 	if (driver == NULL) {
 	    /* configuration error: for shadows, send to postmaster */
 	    send_to_postmaster = TRUE;
-	    write_log(LOG_SYS|LOG_MLOG,
+	    write_log(WRITE_LOG_SYS|WRITE_LOG_MLOG,
 		      "shadow transport %s: driver %s not found",
 		      tp->name, tp->driver);
 	    continue;
@@ -473,7 +473,7 @@ call_transports(asn, defer, fail)
 
 	    for (cur = tp_fail; cur; cur = next) {
 		next = cur->succ;
-		write_log(LOG_SYS, "%s ... shadow transport %s failed: %s",
+		write_log(WRITE_LOG_SYS, "%s ... shadow transport %s failed: %s",
 			  cur->in_addr, cur->transport->name, cur->next_addr);
 		if ((cur->flags & ADDR_SHADOW) == 0) {
 		    /*
@@ -919,7 +919,7 @@ build_path_to_sender()
 
     path_to_sender = build_partial_uucp_route(sender, &error, 0);
     if (path_to_sender == NULL) {
-	write_log(LOG_SYS|LOG_MLOG,
+	write_log(WRITE_LOG_SYS|WRITE_LOG_MLOG,
 		  "error building path to sender, sender=%s, error=%s",
 		  sender, error);
 	path_to_sender = "Postmaster";
