@@ -1,5 +1,5 @@
 /*
-#ident	"@(#)smail/src/transports:RELEASE-3_2_0_101:appendfile.c,v 1.35 1997/04/12 01:47:56 woods Exp"
+#ident	"@(#)smail/src/transports:RELEASE-3_2_0_102:appendfile.c,v 1.36 1998/04/11 23:31:38 woods Exp"
  */
 
 /*
@@ -702,7 +702,7 @@ get_appendfile_ugid(tp, addr, uid, gid)
 	struct passwd *pw = getpwbyname(priv->user);
 
 	if (pw == NULL) {
-	    write_log(LOG_PANIC,
+	    write_log(WRITE_LOG_PANIC,
 		      "transport %s: warning: user %s unknown, using nobody",
 		      tp->name, priv->user);
 	    priv->user = NULL;
@@ -718,7 +718,7 @@ get_appendfile_ugid(tp, addr, uid, gid)
 	struct group *gr = getgrbyname(priv->group);
 
 	if (gr == NULL) {
-	    write_log(LOG_PANIC,
+	    write_log(WRITE_LOG_PANIC,
 		      "transport %s: warning: group %s unknown, ignored",
 		      tp->name, priv->group);
 	    priv->group = NULL;
