@@ -1,5 +1,5 @@
 /*
-#ident	"@(#)smail/src/transports:RELEASE-3_2_0_101:pipe.c,v 1.20 1997/12/01 23:47:29 woods Exp"
+#ident	"@(#)smail/src/transports:RELEASE-3_2_0_102:pipe.c,v 1.24 1998/04/12 01:57:48 woods Exp"
  */
 
 /*
@@ -62,6 +62,9 @@
 #include <signal.h>
 #include <errno.h>
 #include "defs.h"
+#ifdef HAVE_UNISTD_H
+# include <unistd.h>
+#endif
 #include "../config.h"
 #include "../smail.h"
 #include "../dys.h"
@@ -116,7 +119,8 @@ tpd_pipe(addr, succeed, defer, fail)
 {
     register struct pipe_private *priv;	/* pipe driver's private data */
     struct transport *tp = addr->transport;
-    char **argv;			/* args to pass to open_pipe */
+    char *ourcmd;			/* possibly expanded command-line */
+    char **argv;			/* args to pass to open_child */
     FILE *child;			/* child process' stdin */
     int status;				/* exit status from child process */
     int pid;				/* pid of child process */
@@ -159,8 +163,26 @@ tpd_pipe(addr, succeed, defer, fail)
 	insert_addr_list(addr, defer, er);
 	return;
     }
-    /* get the argument vectors for the execv call */
-    argv = build_cmd_line(priv->cmd, addr, "", &error);
+    /*
+     * This is a special trick because if we are not wrapping the command with
+     * /bin/sh (as is preferrable on hosts which support #! since the exit code
+     * won't get lost), then we have to expand the $user string *before* we
+     * start hacking on it in build_cmd_line() else it will not be broken into
+     * separate arguments and execv() will fail.  In theory build_cmd_line()
+     * should probably always do this double expansion itself, but for now this
+     * hack will have to suffice.  In either case quoting rules are messy.
+     */
+    if (*(priv->cmd) == '$') {
+	/* XXX perhaps we should just use substitute()???? */
+	ourcmd = expand_string(priv->cmd, addr, (char *) NULL, (char *) NULL);
+    } else {
+	ourcmd = priv->cmd;		/* should be ``/bin/sh -c ${shquote:user}'' */
+    }
+    /* get the argument vectors for the execv() call */
+    argv = build_cmd_line(ourcmd, addr, "", &error);
+    if (*(priv->cmd) == '$') {
+	xfree(ourcmd);
+    }
     if (argv == NULL) {
 	/*
 	 * ERR_138 - error in cmd attribute
@@ -246,7 +268,7 @@ tpd_pipe(addr, succeed, defer, fail)
 	char *cp;
 	int c;
 
-	fputs("  pipe: exec:", errfile);
+	fputs("  pipe: execv:", errfile);
 	for (argp = argv; *argp; argp++) {
 	    fputs(" \"", errfile);
 	    for (cp = *argp; (c = *cp++); ) {
@@ -311,7 +333,7 @@ tpd_pipe(addr, succeed, defer, fail)
 	    struct addr *cur;
 
 	    for (cur = addr; cur; cur = cur->succ) {
-		write_log(LOG_SYS,
+		write_log(WRITE_LOG_SYS,
 			 "note: %s ... transport %s: write on pipe failed: %s",
 			  addr->in_addr, tp->name, strerror(errno));
 	    }
@@ -328,7 +350,7 @@ tpd_pipe(addr, succeed, defer, fail)
 	     *      not actually read its stdin.  For example, a forward
 	     *      file containing:
 	     *
-	     *		"|mailx -s \"gone fishing\" $SENDER < $HOME/.fishing"
+	     *		"|mailx -s \"gone fishing\" $sender < $HOME/.fishing"
 	     *
 	     *      will send a message to the originator of a message
 	     *      stating that the recipient is on vacation.  However, as
@@ -337,17 +359,24 @@ tpd_pipe(addr, succeed, defer, fail)
 	     *
 	     *      The above problem can be dealt with by setting the
 	     *      ignore_write_errors attribute for the "pipe" transport,
-	     *      or be changing the forward file to:
+	     *      or changing the forward file to use a script such as:
 	     *
-	     *		"|cat>/dev/null;
-	     *		 mailx -s \"gone fishing\" $SENDER < $HOME/.fishing"
+	     *		"|$HOME/bin/gone-fishing"
+	     *
+	     *      And in your ~/bin/gone-fishing script something like
+	     *      the following:
+	     *
+	     *		#! /bin/sh
+	     *		:
+	     *		cat > /dev/null
+	     *		mailx -s "gone fishing" $SENDER < $HOME/.fishing
 	     *
 	     *      which will read and ignore the standard input.
 	     *
 	     *      The last possibility is that a command failed before
-	     *      reading all of stdin, or the exec() failed in
+	     *      reading all of stdin, or the execv() failed in
 	     *      open_child(), or the child shell failed to fork() or
-	     *      exec(), etc.
+	     *      execv(), etc.
 	     *
 	     * ACTIONS
 	     *      Fail the input addresses and send an error to the
@@ -374,7 +403,7 @@ tpd_pipe(addr, succeed, defer, fail)
     }
 
     status = close_child(child, (FILE *)NULL, pid);
-    if (status == EOF && (tp->flags & PIPE_IGNORE_STATUS) == 0) {
+    if (status == -1 && (tp->flags & PIPE_IGNORE_STATUS) == 0) {
 	/*
 	 * ERR_142 - failed to reap child process
 	 *
@@ -434,7 +463,7 @@ tpd_pipe(addr, succeed, defer, fail)
 		struct addr *cur;
 
 		for (cur = addr; cur; cur = cur->succ) {
-		    write_log(LOG_SYS, "note: %s ... %s", cur->in_addr, errstr);
+		    write_log(WRITE_LOG_SYS, "note: %s ... %s", cur->in_addr, errstr);
 		}
 	    } else {
 		insert_addr_list(addr,
@@ -467,16 +496,19 @@ tpd_pipe(addr, succeed, defer, fail)
 	     *      significant, then ignore_status should be set for the
 	     *      transport.
 	     *
-	     *      Note that the normal pipe driver wraps the command in
-	     *      /bin/sh which will likely try to fork() again to exec()
-	     *      the final pipe command.  The exit status therefore may
-	     *      be from the shell and not the final pipe command if, for
-	     *      example, the user is out of processes.  This can be
-	     *      avoided if the pipe command is a simple program and is
-	     *      prefixed with the shell builtin "exec" which will avoid
-	     *      subsequent fork().  If your OS can exec() scripts you
-	     *      might consider eliminating the extra call to /bin/sh
-	     *      from the pipe driver command (eg. use just "$user").
+	     *      Note that on systems without #! support the pipe driver
+	     *      wraps the command in /bin/sh which will likely try to
+	     *      fork() again to exec() the final pipe command.  The exit
+	     *      status therefore may be from the shell and not the final
+	     *      pipe command if, for example, the user is out of processes.
+	     *      This can be avoided if the pipe command is a simple program
+	     *      and is prefixed with the shell builtin "exec" which will
+	     *      avoid subsequent fork().  If your OS has #! support
+	     *      (i.e. it can exec() scripts) the default pipe driver
+	     *      configuration uses just "$user", which will be expanded and
+	     *      then made into an argv[] for exec().  In this case the
+	     *      shell will not be involved and the exit code will most
+	     *      definitely be from the command given.
 	     */
 	    char *errstr =
 		xprintf("transport %s: child returned status %s (%d)",
@@ -490,7 +522,7 @@ tpd_pipe(addr, succeed, defer, fail)
 		struct addr *cur;
 
 		for (cur = addr; cur; cur = cur->succ) {
-		    write_log(LOG_SYS, "note: %s ... %s", cur->in_addr, errstr);
+		    write_log(WRITE_LOG_SYS, "note: %s ... %s", cur->in_addr, errstr);
 		}
 	    } else {
 		insert_addr_list(addr,
@@ -701,7 +733,7 @@ get_pipe_ugid(tp, addr, uid, gid)
 	struct passwd *pw = getpwbyname(priv->user);
 
 	if (pw == NULL) {
-	    write_log(LOG_PANIC,
+	    write_log(WRITE_LOG_PANIC,
 		      "transport %s: warning: user %s unknown, using nobody",
 		      tp->name, priv->user);
 	    priv->user = NULL;
@@ -717,7 +749,7 @@ get_pipe_ugid(tp, addr, uid, gid)
 	struct group *gr = getgrbyname(priv->group);
 
 	if (gr == NULL) {
-	    write_log(LOG_PANIC,
+	    write_log(WRITE_LOG_PANIC,
 		      "transport %s: warning: group %s unknown, ignored",
 		      tp->name, priv->group);
 	    priv->group = NULL;
