@@ -1,5 +1,5 @@
 /*
-#ident	"@(#)smail/src/transports:RELEASE-3_2_0_101:smtplib.c,v 1.29 1997/09/04 17:49:25 woods Exp"
+#ident	"@(#)smail/src/transports:RELEASE-3_2_0_102:smtplib.c,v 1.30 1998/04/11 23:31:46 woods Exp"
  */
 
 /*
@@ -214,7 +214,7 @@ smtp_startup(smtpb, error_p, try_ehlo)
 	       special value here.  Also write a message to the log
 	       file because it is interesting to know which mailers
 	       expose this problem. */
-	    write_log(LOG_SYS, "link broken by EHLO!");
+	    write_log(WRITE_LOG_SYS, "link broken by EHLO!");
 	    return SMTP_EHLO_FAIL;
 	}
 	if (REPLY_GROUP(reply) == NEGATIVE_TRY_AGAIN) {
@@ -317,7 +317,7 @@ smtp_startup(smtpb, error_p, try_ehlo)
 	       to handle malformed EHLO replies: */
 # ifndef NO_LOG_EHLO
 	    /* XXX this is really ugly as it leaves the newlines in place... */
-	    write_log(LOG_SYS, "destination supports esmtp, but is buggy (%s)",
+	    write_log(WRITE_LOG_SYS, "destination supports esmtp, but is buggy (%s)",
 		      reply_text);
 # endif /* not NO_LOG_EHLO */
 	    return SMTP_SUCCEED;
@@ -347,7 +347,7 @@ smtp_startup(smtpb, error_p, try_ehlo)
     }
     if (reply == REPLY_SEQUENCE_ERROR) {
 	/* ignore 503 Bad sequence of commands after EHLO/RSET/HELO */
-	write_log(LOG_SYS, "503 after EHLO/RSET/HELO (%s)",
+	write_log(WRITE_LOG_SYS, "503 after EHLO/RSET/HELO (%s)",
 		  reply_text);
     } else if (reply != REPLY_OK) {
 #ifdef HAVE_EHLO
@@ -367,7 +367,7 @@ smtp_startup(smtpb, error_p, try_ehlo)
 		/* Some gateways don't accept any commands before they get
 		 * a HELO, not even RSET.  Fortunately it is usually safe
 		 * to ignore the error messages. */
-		write_log(LOG_SYS, "unexpected response to RSET (%s)",
+		write_log(WRITE_LOG_SYS, "unexpected response to RSET (%s)",
 			  reply_text);
 	    }
 	    /* the RSET command has been accepted; try again with HELO */
