@@ -1,5 +1,5 @@
 /*
-#ident	"@(#)smail/src/transports:RELEASE-3_2_0_101:tcpsmtp.c,v 1.34 1997/12/16 22:08:52 woods Exp"
+#ident	"@(#)smail/src/transports:RELEASE-3_2_0_102:tcpsmtp.c,v 1.35 1998/02/15 21:15:43 woods Exp"
  */
 
 /*
@@ -616,9 +616,9 @@ tcpsmtp_connect(remote_host, ip_addr, family, service, error)
             *error = xprintf("invalid port: %s", service, error_text);
             return -1;
         }
-    } else if (port == NULL) {
+    } else if (! port) {
         smtp_service = getservbyname(service, "tcp");
-        if (smtp_service == NULL) {
+        if (! smtp_service) {
             *error = xprintf("service name %s not found", service);
             return -1;
         }
