@@ -1,6 +1,6 @@
 #! /bin/sh
 :
-#ident	"@(#)smail/src:RELEASE-3_2_0_101:mkaliases.sh,v 1.11 1997/08/08 05:37:10 woods Exp"
+#ident	"@(#)smail/src:RELEASE-3_2_0_102:mkaliases.sh,v 1.12 1998/04/11 23:28:07 woods Exp"
 #
 #    Copyright (C) 1987, 1988 Ronald S. Karr and Landon Curt Noll
 #    Copyright (C) 1992  Ronald S. Karr
@@ -9,42 +9,68 @@
 # and warranty information.
 
 # mkaliases - create an aliases database for a smail aliasfile director
-#
-# Usage: mkaliases [alias_file]
-#
+
 # Rebuilds the aliasfile X_PATH_ALIASES_FILE_X, or the argument, if given.
 #
 # Different types for the aliasfile are rebuilt in different ways.
 # In the case of lsearch, verification is performed on the file,
 # but no other changes are made.
+#
+# XXX FIXME!!!!  Only rebuilds one alias file.
 
 PATH='X_UTIL_PATH_X:X_SECURE_PATH_X'; export PATH
 
-# XXX FIXME!!!  this should be derived from current configuration....
-#
-ALIASES_TYPE='X_ALIASES_TYPE_X'
-
 # XXX for some reason umask doesn't seem to be inherited properly on some
 # XXX systems such as NetBSD-1.1 and BSDI-1.1....
 # XXX This should be derived from modemask in the current configuration...
 umask 002
 
-if [ $# -eq 0 ] ; then
-	# XXX FIXME?  this should be derived from current configuration....
-	ALIASES_FILE='X_PATH_ALIASES_FILE_X'
-elif [ $# -eq 1 ] ; then
-	if [ -w "$1" ] ; then
-		ALIASES_FILE="$1"
-	else
-		echo "$0: '$1' does not appear to be a regular writable file." 1>&2
-		exit 1
-	fi
-else
-	echo "Usage: $0 [alias_file]" 1>&2
+# XXX FIXME?  this should be derived from current configuration....
+ALIASES_FILE='X_PATH_ALIASES_FILE_X'
+
+# XXX FIXME!!!  this should be derived from current configuration....
+ALIASES_TYPE='X_ALIASES_TYPE_X'
+
+prog=$0
+GETOPT="X_UTIL_BIN_DIR_X/getopt"
+
+USAGE="Usage: $prog [-v N] [alias_file [alias_type]"
+
+set -- `$GETOPT v: $*`
+
+if [ $? -ne 0 ]; then
+	echo $USAGE 1>&2
 	exit 2
 fi
 
-# NOTE: list of types defined in lookup.c:protos[]
+for i in $*; do
+	case $i in
+	-v) DEBUG=$2; shift 2;;
+	--) shift; break;;
+	esac
+done
+
+if [ $# -gt 0 ]; then
+	ALIASES_FILE="$1"
+	shift
+fi
+
+if [ $# -gt 0 ]; then
+	ALIASES_TYPE="$1"
+	shift
+fi
+
+if [ ! -w "$ALIASES_FILE" ] ; then
+	echo "$prog: '$ALIASES_FILE' does not appear to be a regular writable file." 1>&2
+	exit 1
+fi
+
+if [ ! -w "`dirname $ALIASES_FILE`" ] ; then
+	echo "$prog: directory '`dirname $ALIASES_FILE`' does not appear to be writable." 1>&2
+	exit 1
+fi
+
+# NOTE: list of possible types defined in lookup.c:protos[]
 #
 case "$ALIASES_TYPE" in
 aliasyp | yp | nialias | nisplus )
