@@ -1,4 +1,6 @@
-/* @(#) mkdbm.c,v 1.13 1997/12/17 19:33:44 woods Exp */
+/*
+#ident	"@(#)smail/util:RELEASE-3_2_0_102:mkdbm.c,v 1.16 1998/08/02 17:07:08 woods Exp"
+ */
 
 /*
  *    Copyright (C) 1987, 1988 Ronald S. Karr and Landon Curt Noll
@@ -118,7 +120,10 @@ main(argc, argv)
 	}
     }
 
-    temp_name = build_temp_name(out_name);
+    if (!(temp_name = build_temp_name(out_name))) {
+	    (void) fprintf(stderr, "%s: %s: %s\n", program, out_name, strerror(errno));
+	    done(EX_CANTCREAT);
+    }
     create_database(temp_name);
 
     if (*files) {
@@ -170,7 +175,7 @@ add_yp_stamps()
 {
 	datum key_lastmod, val_lastmod;
 	datum key_master,  val_master;
-	long now;
+	time_t now;
 	char nows[32];
 
 #ifdef HAVE_GETHOSTNAME
@@ -218,7 +223,7 @@ add_yp_stamps()
 #endif	/* HAVE_GETHOSTNAME */
 
 	(void) time(&now);
-	sprintf(nows, "%10.10ld", now);
+	sprintf(nows, "%10.10ld", (long) now);
 
 	key_lastmod.dptr  = "YP_LAST_MODIFIED";
 	key_lastmod.dsize = strlen(key_lastmod.dptr);
@@ -327,13 +332,16 @@ build_temp_name(name)
     char *name;
 {
     char *fn;
-    char *slash = rindex(name, '/');
+    int dirlen;
+    char *slash = strrchr(name, '/');
+
     extern char *mktemp();
 
     if (slash) {
-	fn = xmalloc((unsigned)(slash - name + sizeof("/dbmXXXXXX")));
-	(void) strncpy(fn, name, slash - name);
-	(void) strcat(fn, "/dbmXXXXXX");
+	dirlen = slash - name;
+	fn = xmalloc((unsigned) (dirlen + sizeof("/dbmXXXXXX")));
+	(void) strncpy(fn, name, dirlen);
+	(void) strcpy(fn + dirlen, "/dbmXXXXXX");
     } else {
 	fn = xmalloc(sizeof("dbmXXXXXX"));
 	strcpy(fn, "dbmXXXXXX");
@@ -348,7 +356,7 @@ static void
 create_database(dbm_name)
     char *dbm_name;
 {
-#ifndef DBM_SUFFIX	/* db emulation of ndbm */
+#ifndef DBM_SUFFIX	/* not db emulation of ndbm */
     int fd;
 #endif
     int temp_len = strlen(dbm_name);
