@@ -223,7 +223,7 @@ done
 ##   exit 1
 ## fi
 
-CATEGORIES="smail smail-contrib smail-docs"
+CATEGORIES="smail smail-util smail-pd smail-contrib smail-samples"
 
 ## if [ -z "$CATEGORIES" ]; then
 ##   echo "$COMMAND: the categories list for $GNATS_SITE was empty!"
