@@ -1,4 +1,6 @@
-/* @(#) unsharmap.c,v 1.11 1997/12/16 22:07:42 woods Exp */
+/*
+#ident	"@(#)smail/util:RELEASE-3_2_0_102:unsharmap.c,v 1.13 1998/08/02 17:07:55 woods Exp"
+ */
 /*
  *    Copyright (C) 1988 Ronald S. Karr and Landon Curt Noll
  *    Copyright (C) 1992 Ronald S. Karr
@@ -62,6 +64,7 @@
  * exits by 0 if there was no errors, non-0 otherwise.
  */
  
+#include <sys/types.h>
 #include <stdio.h>
 #include "defs.h"
 #ifdef HAVE_STDLIB_H
@@ -111,12 +114,18 @@ char *xmalloc();			/* for string.c and strcolon()*/
 char *xrealloc();			/* for string.c and strcolon() */
 void xfree();
 
+/* variables imported by this file */
+extern char *optarg;			/* the option argument */
+extern int optind;			/* operand index */
+
 /* functions imported by this file */
 #if !defined(HAVE_STDLIB_H) && !defined(HAVE_MALLOC_H)
 extern char *malloc();
 extern char *realloc();
 extern void free();				/* int on SunOS */
 #endif
+extern time_t time();
+extern char *ctime();
 extern int creat();
 extern char *strcolon();		/* grap strcolon() from src/string.c */
 
@@ -132,8 +141,6 @@ main( argc, argv )
     int header;				/* HEADER_OK,ERROR,SKIP */
     int errors=0;			/* number of problems found */
     FILE *article;			/* input article stream */
-    extern char *optarg;		/* the option argument */
-    extern int optind;			/* operand index */
 
     /*
      * parse args
@@ -287,9 +294,7 @@ main( argc, argv )
 char *
 get_date()
 {
-    extern long time();
-    long clock = time((long *)0);   /* seconds since 1-jan-1970 0:00:00 GMT */
-    char *ctime();		    /* convert clock into string */
+    time_t clock = time((time_t *) NULL);   /* seconds since 1-jan-1970 0:00:00 GMT */
 
     return(ctime(&clock));
 }
